@@ -62,9 +62,11 @@ code from qwriter:
 #include "gui_utils.h"
 #include "textproc.h"
 
+using namespace std;
 
 QHash <QString, QString> global_palette;
 QSettings *settings;
+
 QMenu *current_files_menu;
 int recent_list_max_items;
 bool b_recent_off;
@@ -154,7 +156,7 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
         {
          QStringList lt = i.next().split(",");
          if (lt.size() > 0)
-             if (lt[0] == file_name)
+             if (lt.at(0) == file_name)
                 i.remove();
         }
 
@@ -213,9 +215,6 @@ CDocument::CDocument (QObject *parent): QObject (parent)
 {
   QString fname = tr ("new[%1]").arg (QTime::currentTime().toString ("hh-mm-ss"));
 
-  fnameswoexts.insert ("configure", "sh");
-  fnameswoexts.insert ("install-sh", "sh");
-
   markup_mode = "HTML";
   file_name = fname;
   cursor_xy_visible = true;
@@ -237,6 +236,8 @@ CDocument::CDocument (QObject *parent): QObject (parent)
 
 CDocument::~CDocument()
 {
+//  qDebug() << "CDocument::~CDocument()";
+
   if (file_name.endsWith (".notes") && textEdit->document()->isModified())
      save_with_name_plain (file_name);
   else
@@ -315,8 +316,9 @@ CDox::~CDox()
 {
   b_destroying_all = true;
 
-  while (! list.isEmpty())
-        delete list.takeFirst();
+  if (items.size() > 0)
+     for (vector <size_t>::size_type i = 0; i < items.size(); i++)
+          delete items[i];
 
   qstring_save (recent_list_fname, recent_files.join ("\n"));
 
@@ -332,7 +334,7 @@ CDocument* CDox::create_new()
 
   doc->holder = this;
   doc->markup_mode = markup_mode;
-  list.append (doc);
+  items.push_back (doc);
 
   doc->create_new();
 
@@ -350,13 +352,13 @@ CDocument* CDox::create_new()
 
 CDocument* CDox::get_document_by_fname (const QString &fileName)
 {
-  if (fileName.isEmpty())
+  if (fileName.isEmpty() || items.size() == 0)
      return NULL;
 
-  foreach (CDocument *d, list)
-          if (d->file_name == fileName)
-              return d;
-
+  for (vector <CDocument *>::iterator i = items.begin(); i != items.end(); i++)
+       if ((*i)->file_name == fileName)
+          return *i;
+ 
   return NULL;
 }
 
@@ -390,7 +392,7 @@ CDocument* CDox::open_file (const QString &fileName, const QString &codec)
   doc->update_status();
   doc->update_title (settings->value ("full_path_at_window_title", 1).toBool());
 
-  tab_widget->setCurrentIndex (tab_widget->indexOf (doc->tab_page));
+  main_tab_widget->setCurrentIndex (0);
 
   update_current_files_menu();
 
@@ -403,9 +405,8 @@ void CDox::close_by_idx (int i)
   if (i < 0)
      return;
 
-  CDocument *d = list[i];
-  list.removeAt (i);
-  delete d;
+  delete items[i];
+  items.erase (items.begin() + i);
 
   update_current_files_menu();
 }
@@ -423,7 +424,7 @@ CDocument* CDox::get_current()
   if (i < 0)
      return NULL;
 
-  return list[i];
+  return items[i];
 }
 
 
@@ -489,7 +490,6 @@ QString CDocument::get_filename_at_cursor()
       x = x.mid (i + 1);
 
       result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
-      //qDebug() << "in cur dir: " << result;
       return result;
      }
   else
@@ -534,7 +534,6 @@ CSyntaxHighlighterQRegExp::CSyntaxHighlighterQRegExp (QTextDocument *parent, CDo
 
 
 #if QT_VERSION >= 0x050000
-//#if QT_VERSION_MAJOR >= 5
 CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression (QTextDocument *parent, CDocument *doc, const QString &fname):
                                                                             CSyntaxHighlighter (parent, doc, fname)
 {
@@ -559,12 +558,6 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
   else
       ext = theext;
 
-  if (ext.isEmpty())
-     {
-      QFileInfo fi (file_name);
-      ext = fnameswoexts[fi.fileName()];
-     }
-
   if (ext.isEmpty())
      return;
 
@@ -573,7 +566,6 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
      return;
 
 #if QT_VERSION >= 0x050000
-//#if (QT_VERSION_MAJOR >= 5)
 
   if (settings->value ("qregexpsyntaxhl", 0).toBool())
      highlighter = new CSyntaxHighlighterQRegExp (textEdit->document(), this, fname);
@@ -643,7 +635,6 @@ void CDox::apply_settings_single (CDocument *d)
   QString back_color = hash_get_val (global_palette, "background", "white");
   d->textEdit->margin_color = QColor (hash_get_val (global_palette, "margin_color", text_color)).darker(darker_val);
   d->textEdit->linenums_bg = QColor (hash_get_val (global_palette, "linenums_bg", back_color)).darker(darker_val);
-
   d->textEdit->set_word_wrap (settings->value ("word_wrap", true).toBool());
 
   d->textEdit->repaint();
@@ -653,8 +644,11 @@ void CDox::apply_settings_single (CDocument *d)
 
 void CDox::apply_settings()
 {
-  foreach (CDocument *d, list)
-          apply_settings_single (d);
+  if (items.size() == 0)
+     return;
+
+  for (vector <size_t>::size_type i = 0; i < items.size(); i++)
+      apply_settings_single (items[i]);
 }
 
 
@@ -854,9 +848,9 @@ CTEAEdit::CTEAEdit (QWidget *parent): QPlainTextEdit (parent)
   lineNumberArea = new CLineNumberArea (this);
 
   connect(this, SIGNAL(selectionChanged()), this, SLOT(slot_selectionChanged()));
-
   connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth(int)));
   connect(this, SIGNAL(updateRequest(const QRect &, int)), this, SLOT(updateLineNumberArea(const QRect &, int)));
+
   updateLineNumberAreaWidth (0);
 
   margin_pos = 72;
@@ -920,7 +914,6 @@ void CDox::move_cursor_y (double v)
      move_cursor (QTextCursor::Up);
   if (v > 0)
      move_cursor (QTextCursor::Down);
-  qDebug() << v;
 }
 
 
@@ -940,7 +933,6 @@ CDox::CDox()
   timer = new QTimer (this);
   timer->setInterval (100);
 
-
 #if defined(JOYSTICK_SUPPORTED)
   joystick = new CJoystick (0, this);
 
@@ -952,7 +944,6 @@ CDox::CDox()
          timer->start();
      }
 #endif
-
 }
 
 
@@ -1023,7 +1014,6 @@ QTextCharFormat tformat_from_style (const QString &fontstyle, const QString &col
 
 
 #if QT_VERSION >= 0x050000
-//#if (QT_VERSION_MAJOR >= 5)
 
 void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 {
@@ -1038,6 +1028,9 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
      return;
 
   QString temp = qstring_load (fname);
+  if (temp.isEmpty())
+     return;
+
   QXmlStreamReader xml (temp);
 
   while (! xml.atEnd())
@@ -1046,14 +1039,6 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 
          QString tag_name = xml.name().toString().toLower();
 
-/*
-         if (xml.isStartElement())
-            if (tag_name == "document")
-               {
-                exts = xml.attributes().value ("exts").toString();
-                langs = xml.attributes().value ("langs").toString();
-               }
-*/
          if (xml.isStartElement())
             {
 
@@ -1106,11 +1091,11 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                                        HighlightingRule rule;
                                        rule.pattern = rg;
                                        rule.format = fmt;
-                                       highlightingRules.append (rule);
+                                       highlightingRules.push_back (rule);
                                       }
                                   }
                          }
-                      else
+                      else //current, good format
                       if (xml_format == 1)
                          {
                           HighlightingRule rule;
@@ -1123,7 +1108,7 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                                HighlightingRule rule;
                                rule.pattern = rg;
                                rule.format = fmt;
-                               highlightingRules.append (rule);
+                               highlightingRules.push_back (rule);
                               }
                          }
 
@@ -1144,7 +1129,7 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                              HighlightingRule rule;
                              rule.pattern = rg;
                              rule.format = fmt;
-                             highlightingRules.append (rule);
+                             highlightingRules.push_back (rule);
                             }
                        }
                     else
@@ -1173,10 +1158,10 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 
                      }//item
 
-       }//is start
+       }//end of "is start"
 
-  if (xml.hasError())
-     qDebug() << "xml parse error";
+   if (xml.hasError())
+      qDebug() << "xml parse error";
 
   } //cycle
 }
@@ -1184,20 +1169,28 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 
 void CSyntaxHighlighterQRegularExpression::highlightBlock (const QString &text)
 {
-  foreach (HighlightingRule rule, highlightingRules)
-          {
-           QRegularExpressionMatch m = rule.pattern.match (text);
+  if (highlightingRules.size() == 0)
+     return;
 
-           int index = m.capturedStart();
+  for (std::vector <HighlightingRule>::iterator it = highlightingRules.begin(); it != highlightingRules.end(); it++)
+      {
+       QRegularExpressionMatch m = it->pattern.match (text);
+       if (! m.isValid())
+           continue;
 
-           while (index >= 0)
-                 {
-                  int length = m.capturedLength();
-                  setFormat (index, length, rule.format);
-                  m = rule.pattern.match (text, index + length);
-                  index = m.capturedStart();
-                 }
-          }
+       int index = m.capturedStart();
+
+       while (index >= 0)
+             {
+              int length = m.capturedLength();
+              setFormat (index, length, it->format);
+              m = it->pattern.match (text, index + length);
+              if (! m.isValid())  
+                  break;
+
+              index = m.capturedStart();
+             }
+       }
 
   setCurrentBlockState (0);
 
@@ -1244,14 +1237,15 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
 
   exts = "default";
   langs = "default";
-
   cs = Qt::CaseSensitive;
 
   if (! file_exists (fname))
      return;
 
-
   QString temp = qstring_load (fname);
+  if (temp.isEmpty())
+     return;
+
   QXmlStreamReader xml (temp);
 
   while (! xml.atEnd())
@@ -1259,14 +1253,7 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
          xml.readNext();
 
          QString tag_name = xml.name().toString().toLower();
-/*
-         if (xml.isStartElement())
-            if (tag_name == "document")
-                {
-                 exts = xml.attributes().value ("exts").toString();
-                 langs = xml.attributes().value ("langs").toString();
-                }
-*/
+
          if (xml.isStartElement())
             {
              if (tag_name == "document")
@@ -1282,11 +1269,6 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
 
                  if (attr_name == "options")
                     {
-                    /* QString s_wrap = xml.attributes().value ("wrap").toString();
-                     if (! s_wrap.isEmpty())
-                        if (s_wrap == "0" || s_wrap == "false")
-                           wrap = false;*/
-
                      QString s_casecare = xml.attributes().value ("casecare").toString();
                      if (! s_casecare.isEmpty())
                         if (s_casecare == "0" || s_casecare == "false")
@@ -1314,7 +1296,7 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
                                      HighlightingRule rule;
                                      rule.pattern = rg;
                                      rule.format = fmt;
-                                     highlightingRules.append (rule);
+                                     highlightingRules.push_back (rule);
                                     }
                                 }
                           }
@@ -1330,7 +1312,7 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
                                   HighlightingRule rule;
                                   rule.pattern = QRegExp (xml.readElementText().trimmed().remove('\n'), cs);
                                   rule.format = fmt;
-                                  highlightingRules.append(rule);
+                                  highlightingRules.push_back (rule);
                                  }
                             }
 
@@ -1347,7 +1329,7 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
                          HighlightingRule rule;
                          rule.pattern = rg;
                          rule.format = fmt;
-                         highlightingRules.append (rule);
+                         highlightingRules.push_back (rule);
                         }
                     }
                  else
@@ -1386,20 +1368,20 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
 
 void CSyntaxHighlighterQRegExp::highlightBlock (const QString &text)
 {
+  if (highlightingRules.size() == 0)
+     return;
 
-  foreach (HighlightingRule rule, highlightingRules)
-          {
-           int index;
+  for (std::vector <HighlightingRule>::iterator it = highlightingRules.begin(); it != highlightingRules.end(); it++)
+      {
+       int index = text.indexOf (it->pattern);
 
-           index = text.indexOf (rule.pattern);
-
-           while (index >= 0)
-                 {
-                  int length = rule.pattern.matchedLength();
-                  setFormat (index, length, rule.format);
-                  index = text.indexOf (rule.pattern, index + length);
-                 }
-           }
+       while (index >= 0)
+             {
+              int length = it->pattern.matchedLength();
+              setFormat (index, length, it->format);
+              index = text.indexOf (it->pattern, index + length);
+             }
+       }
 
   setCurrentBlockState (0);
 
@@ -1413,10 +1395,10 @@ void CSyntaxHighlighterQRegExp::highlightBlock (const QString &text)
 
   while (startIndex >= 0)
         {
-//         int endIndex = text.indexOf (commentEndExpression, startIndex);
          int endIndex = commentEndExpression.indexIn (text, startIndex);
 
          int commentLength;
+
          if (endIndex == -1)
             {
              setCurrentBlockState (1);
@@ -1433,21 +1415,21 @@ void CSyntaxHighlighterQRegExp::highlightBlock (const QString &text)
 
 void CDox::save_to_session (const QString &fileName)
 {
-  if (list.size() < 0)
+  if (items.size() == 0)
      return;
 
   fname_current_session = fileName;
   QString l;
 
-  foreach (CDocument *d, list)
+  for (vector <CDocument*>::iterator i = items.begin(); i != items.end(); i++)
+      {
+       QString t = (*i)->get_triplex();
+       if (! t.isEmpty())
           {
-           QString t = d->get_triplex();
-           if (! t.isEmpty())
-               {
-                l += t;
-                l += "\n";
-               }
+           l += t;
+           l += "\n";
           }
+      }
 
   qstring_save (fileName, l.trimmed());
 }
@@ -1462,185 +1444,13 @@ void CDox::load_from_session (const QString &fileName)
   if (l.size() < 0)
      return;
 
-  foreach (QString t, l)
-          open_file_triplex (t);
+  for (int i = 0; i < l.size(); i++)
+      open_file_triplex (l[i]);
+
 
   fname_current_session = fileName;
 }
 
-/*
-QHash <QString, QString> CDox::load_eclipse_theme_xml (const QString &fname)
-{
-  QHash <QString, QString> result;
-
-  QString temp = qstring_load (fname);
-  QXmlStreamReader xml (temp);
-
-   while (! xml.atEnd())
-        {
-         xml.readNext();
-
-         QString tag_name = xml.name().toString();
-
-         if (xml.isStartElement())
-            {
-
-            if (tag_name == "colorTheme")
-             {
-
-                 log->log (xml.attributes().value ("id").toString());
-                 log->log (xml.attributes().value ("name").toString());
-                 log->log (xml.attributes().value ("modified").toString());
-                 log->log (xml.attributes().value ("author").toString());
-                 log->log (xml.attributes().value ("website").toString());
-                }
-
-
-            if (tag_name == "singleLineComment")
-               {
-                QString t = xml.attributes().value ("color").toString();
-                if (! t.isEmpty())
-                     result.insert ("single comment", t);
-               }
-
-
-            if (tag_name == "class")
-               {
-                QString t = xml.attributes().value ("color").toString();
-                if (! t.isEmpty())
-                   {
-                    result.insert ("class", t);
-                    result.insert ("type", t);
-                   }
-               }
-
-
-         if (tag_name == "operator")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                     result.insert ("operator", t);
-            }
-
-
-
-         if (tag_name == "string")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                 result.insert ("quotes", t);
-            }
-
-
-
-         if (tag_name == "multiLineComment")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                 result.insert ("mcomment-start", t);
-            }
-
-
-
-         if (tag_name == "foreground")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                 {
-                  result.insert ("text", t);
-                  result.insert ("functions", t);
-                  result.insert ("modifiers", t);
-                  result.insert ("margin_color", t);
-                  result.insert ("digits", t);
-                  result.insert ("digits-float", t);
-                  result.insert ("label", t);
-                  result.insert ("include", t);
-                  result.insert ("preproc", t);
-                 }
-             }
-
-         if (tag_name == "background")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                {
-                 result.insert ("background", t);
-                 result.insert ("linenums_bg", t);
-                }
-            }
-
-
-         if (tag_name == "selectionForeground")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                result.insert ("sel-text", t);
-            }
-
-
-
-         if (tag_name == "selectionBackground")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-               result.insert ("sel-background", t);
-            }
-
-
-         if (tag_name == "keyword")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                {
-                 result.insert ("keywords", t);
-                result.insert ("tags", t);
-                }
-             }
-
-
-
-       	 if (tag_name == "currentLine")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                result.insert ("cur_line_color", t);
-            }
-
-
-         if (tag_name == "bracket")
-            {
-             QString t = xml.attributes().value ("color").toString();
-             if (! t.isEmpty())
-                 result.insert ("brackets", t);
-             }
-
-        }//is start
-
-  if (xml.hasError())
-     qDebug() << "xml parse error";
-
-  } //cycle
-
-
-   result.insert ("error", "red");
-
-   return result;
-}
-*/
-/*
-void CDox::load_global_palette (const QString &fileName)
-{
-  if (! file_exists (fileName))
-      return;
-
-  global_palette.clear();
-
-  if (file_get_ext (fileName) == "xml")
-     global_palette = load_eclipse_theme_xml (fileName);
-  else
-      global_palette = hash_load_keyval (fileName);
-}
-*/
 
 QString CDocument::get_selected_text() const
 {
@@ -1783,7 +1593,6 @@ void CTEAEdit::un_indent()
 #define SK_D 40
 #define SK_W 25
 #define SK_S 39
-
 #define SK_E 26
 #define SK_C 54
 
@@ -2123,27 +1932,22 @@ void CTEAEdit::braceHighlight()
 
 bool CTEAEdit::has_rect_selection()
 {
- if (rect_sel_start.y() == -1 || rect_sel_end.y() == -1)
+  if (rect_sel_start.y() == -1 || rect_sel_end.y() == -1)
      return false;
 
- return true;
+  return true;
 }
 
 
 void CTEAEdit::update_rect_sel()
 {
- // qDebug() << "CTEAEdit::update_rect_sel()  -1";
-
   if (rect_sel_start.y() == -1 || rect_sel_end.y() == -1)
      return;
 
   QTextEdit::ExtraSelection rect_selection;
 
-  //extraSelections.clear();
-
   int y1 = std::min (rect_sel_start.y(), rect_sel_end.y());
   int y2 = std::max (rect_sel_start.y(), rect_sel_end.y());
-  //int ydiff = y2 - y1;
 
   int x1 = std::min (rect_sel_start.x(), rect_sel_end.x());
   int x2 = std::max (rect_sel_start.x(), rect_sel_end.x());
@@ -2158,16 +1962,10 @@ void CTEAEdit::update_rect_sel()
 
   for (int y = y1; y <= y2; y++)
       {
-//       qDebug() << "y:" << y;
-
        QTextBlock b = document()->findBlockByNumber (y);
 
-   //    qDebug() << "b.text().length(): " << b.text().length();
-     //  qDebug() << "x1: " << x1;
-
        if (b.text().length() == 0)
           {
-           //cursor.movePosition (QTextCursor::NextBlock, QTextCursor::MoveAnchor);
            correction++;
            continue;
           }
@@ -2178,11 +1976,9 @@ void CTEAEdit::update_rect_sel()
           sel_len = b.text().length() - x1;
 
        cursor.movePosition (QTextCursor::Right, QTextCursor::MoveAnchor, x1 + correction);
-
        cursor.movePosition (QTextCursor::Right, QTextCursor::KeepAnchor, sel_len);
 
        rect_selection.cursor = cursor;
-       // rect_selection.format.setBackground (brackets_color);
        rect_selection.format.setBackground (sel_back_color);
        rect_selection.format.setForeground (sel_text_color);
 
@@ -2192,18 +1988,9 @@ void CTEAEdit::update_rect_sel()
 
        if (b.text().length() != 0)
            correction = 0;
-
       }
 
   setExtraSelections (extraSelections);
- /*
-  qDebug() << "ydiff: " << ydiff;
-  qDebug() << "y1:" << y1;
-  qDebug() << "y2:" << y2;
-  qDebug() << "x1:" << x1;
-  qDebug() << "x2:" << x2;
-  */
- // qDebug() << get_rect_sel();
 }
 
 
@@ -2218,8 +2005,6 @@ void CTEAEdit::rect_sel_replace (const QString &s, bool insert)
 4. Заменяем старый текст на выходной буфер.
 
 */
-
-
   int y1 = std::min (rect_sel_start.y(), rect_sel_end.y());
   int y2 = std::max (rect_sel_start.y(), rect_sel_end.y());
   int ydiff = y2 - y1;
@@ -2229,7 +2014,6 @@ void CTEAEdit::rect_sel_replace (const QString &s, bool insert)
   int x2 = std::max (rect_sel_start.x(), rect_sel_end.x());
 
 //  int how_many_copy_from_source = ydiff;
-
 //  int lines_to_end = blockCount() - y1;
 
   QStringList sl_source;
@@ -2281,79 +2065,8 @@ void CTEAEdit::rect_sel_replace (const QString &s, bool insert)
   cursor.removeSelectedText();
 
   textCursor().insertText (new_text);
-
-//  qDebug() << new_text;
 }
 
-/*
-void CTEAEdit::rect_sel_insert (const QString &s)
-{
-
-  int y1 = std::min (rect_sel_start.y(), rect_sel_end.y());
-  int y2 = std::max (rect_sel_start.y(), rect_sel_end.y());
-  int ydiff = y2 - y1;
-
-
-  int x1 = std::min (rect_sel_start.x(), rect_sel_end.x());
-  int x2 = std::max (rect_sel_start.x(), rect_sel_end.x());
-  int xdiff = x2 - x1;
-
-  int how_many_copy_from_source = ydiff;
-
-  int lines_to_end = blockCount() - y1;
-
-  if (ydiff > lines_to_end)
-     how_many_copy_from_source = lines_to_end;
-
-  QStringList sl_source;
-
-  for (int line = y1; line <= y2; line++)
-      {
-       QTextBlock b = document()->findBlockByNumber (line);
-       sl_source.append (b.text());
-      }
-
-  QStringList sl_insert = s.split ("\n");
-
-  QStringList sl_dest;
-
-  for (int line = 0; line < sl_insert.size(); line++)
-      {
-       QString t;
-
-       if (line >= sl_source.size())
-          {
-           t = sl_insert [line];
-           sl_dest.append (t);
-           continue;
-          }
-
-       t = sl_source[line].left (x1);
-       t += sl_insert [line];
-       t += sl_source[line].mid (x1);
-
-       sl_dest.append (t);
-      }
-
-  QString new_text = sl_dest.join ("\n");
-  //new_text += "\n";
-
-//теперь выделить при помощи курсора всё от y1 до y2 и обычным способом заменить текст
-
-  QTextCursor cursor = textCursor();
-
-  cursor.movePosition (QTextCursor::Start, QTextCursor::MoveAnchor);
-  cursor.movePosition (QTextCursor::NextBlock, QTextCursor::MoveAnchor, y1);
-  cursor.movePosition (QTextCursor::NextBlock, QTextCursor::KeepAnchor, ydiff);
-  cursor.movePosition (QTextCursor::EndOfBlock, QTextCursor::KeepAnchor);
-
-  cursor.removeSelectedText();
-
-  textCursor().insertText (new_text);
-
-  qDebug() << new_text;
-}
- */
 
 bool CTEAEdit::canInsertFromMimeData (const QMimeData *source)
 {
@@ -2392,13 +2105,15 @@ void CTEAEdit::insertFromMimeData (const QMimeData *source)
       return;
      }
 
-  foreach (QUrl u, source->urls())
-          {
-           fName = u.toLocalFile();
-           info.setFile(fName);
-           if (info.isFile())
-              doc->holder->open_file (fName, "UTF-8");
-          }
+   QList<QUrl> l = source->urls();
+
+   for (QList <QUrl>::iterator u = l.begin(); u != l.end(); u++)
+       {
+        fName = u->toLocalFile();
+        info.setFile(fName);
+        if (info.isFile())
+           doc->holder->open_file (fName, "UTF-8");
+       }
 }
 
 
@@ -2450,10 +2165,11 @@ void CDox::open_current()
 
 void CDox::update_current_files_menu()
 {
- QStringList current_files;
+  QStringList current_files;
 
-  foreach (CDocument *d, list)
-          current_files.prepend (d->file_name);
+  if (items.size() > 0)
+     for (vector <size_t>::size_type i = 0; i < items.size(); i++)
+         current_files.prepend (items[i]->file_name);
 
   current_files_menu->clear();
   create_menu_from_list (this, current_files_menu, current_files, SLOT(open_current()));
@@ -2475,22 +2191,15 @@ QString CTEAEdit::get_rect_sel()
 
   int y1 = std::min (rect_sel_start.y(), rect_sel_end.y());
   int y2 = std::max (rect_sel_start.y(), rect_sel_end.y());
-  //int ydiff = y2 - y1;
 
   int x1 = std::min (rect_sel_start.x(), rect_sel_end.x());
   int x2 = std::max (rect_sel_start.x(), rect_sel_end.x());
-  int xdiff = x2 - x1;
+  int xdiff = x2 - x1; //sel length
 
 
   for (int y = y1; y <= y2; y++)
       {
-       //int sel_len = xdiff;
-
        QTextBlock b = document()->findBlockByNumber (y);
-
-       //if ((b.text().length() - x1) < xdiff)
-         // sel_len = b.text().length() - x1;
-
        QString t = b.text();
 
        result += t.mid (x1, xdiff);
@@ -2595,91 +2304,6 @@ void CTEAEdit::text_replace (const QString &s)
       textCursor().insertText (s);
 }
 
-/*
-void CTEAEdit::copy()
-{
-  qDebug() << "CTEAEdit::copy()";
-
-  if (has_rect_selection())
-     QApplication::clipboard()->setText (get_rect_sel());
-  else
-      QPlainTextEdit::copy();
-}
-*/
-
-/*
- *
-
- // new INDEX-IN VARIANT
-
-void CSyntaxHighlighter::highlightBlock (const QString &text)
-{
- qDebug() << "1";
-
-  foreach (HighlightingRule rule, highlightingRules)
-          {
-           QRegExp expression (rule.pattern);
-
-           int index;
-
-           if (! casecare)
-              index = expression.indexIn (text.toLower());
-           else
-               index = expression.indexIn (text);
-
-           while (index >= 0)
-                 {
-                  int length = expression.matchedLength();
-                  setFormat (index, length, rule.format);
-
-                  if (! casecare)
-                      index = expression.indexIn (text.toLower(), index + length);
-                  else
-                      index = expression.indexIn (text, index + length);
-                 }
-           }
-
-  setCurrentBlockState (0);
-
-  int startIndex = 0;
-
-  if (commentStartExpression.isEmpty() || commentEndExpression.isEmpty())
-     return;
-
-  if (previousBlockState() != 1)
-     {
-      if (! casecare)
-         startIndex = commentStartExpression.indexIn (text.toLower());
-      else
-         startIndex = commentStartExpression.indexIn (text);
-     }
-
-  while (startIndex >= 0)
-        {
-         int endIndex;
-         if (! casecare)
-            endIndex = commentEndExpression.indexIn (text.toLower(), startIndex);
-         else
-            endIndex = commentEndExpression.indexIn (text, startIndex);
-
-         int commentLength;
-         if (endIndex == -1)
-            {
-             setCurrentBlockState (1);
-             commentLength = text.length() - startIndex;
-            }
-         else
-             commentLength = endIndex - startIndex + commentEndExpression.matchedLength();
-
-         setFormat (startIndex, commentLength, multiLineCommentFormat);
-
-         if (! casecare)
-            startIndex = commentStartExpression.indexIn (text.toLower(), startIndex + commentLength);
-         else
-            startIndex = commentStartExpression.indexIn (text, startIndex + commentLength);
-        }
-}
-*/
 
 void CDox::move_cursor (QTextCursor::MoveOperation mo)
 {
@@ -2704,7 +2328,6 @@ void CDox::move_cursor (QTextCursor::MoveOperation mo)
 
 bool CDox::event (QEvent *ev)
 {
-
   if (static_cast<int>(ev->type() == evtJoystickAxis))
      {
       CJoystickAxisEvent* custom_event = reinterpret_cast<CJoystickAxisEvent*>(ev);
@@ -2717,8 +2340,6 @@ bool CDox::event (QEvent *ev)
 }
 
 
-
-
 void CDox::handle_joystick_event (CJoystickAxisEvent *event)
 {
   QTextCursor::MoveOperation mo = QTextCursor::NoMove;
@@ -2745,11 +2366,11 @@ void CDox::handle_joystick_event (CJoystickAxisEvent *event)
 void CDox::update_project (const QString &fileName)
 {
   if (file_get_ext (fileName) == "teaproject")
-    {
-     fname_current_project = fileName;
-     hash_project.clear();
-     hash_project = hash_load_keyval (fileName);
-    }
+     {
+      fname_current_project = fileName;
+      hash_project.clear();
+      hash_project = hash_load_keyval (fileName);
+     }
 }
 
 
@@ -2759,15 +2380,15 @@ void CTEAEdit::set_word_wrap (bool wrap)
      setWordWrapMode (QTextOption::WrapAtWordBoundaryOrAnywhere);
   else
      setWordWrapMode (QTextOption::NoWrap);
-
-
 }
 
+
 bool CTEAEdit::get_word_wrap()
 {
-  if (wordWrapMode() == QTextOption::WrapAtWordBoundaryOrAnywhere)
-     return true;
+  return wordWrapMode() == QTextOption::WrapAtWordBoundaryOrAnywhere;
+  /*if (wordWrapMode() == QTextOption::WrapAtWordBoundaryOrAnywhere)
+      return true;
   else
-     return false;
-
+      return false;*/
 }
+
