@@ -36,6 +36,7 @@ code from qwriter:
 #ifndef DOCUMENT_H
 #define DOCUMENT_H
 
+#include <vector>
 
 #include <QPoint>
 #include <QStatusBar>
@@ -44,13 +45,11 @@ code from qwriter:
 #include <QPlainTextEdit>
 #include <QSyntaxHighlighter>
 
-
 #if QT_VERSION >= 0x050000
 #include <QRegularExpression>
 #endif
 
-
-#if defined(JOYSTICK_SUPPORTED)
+#if defined (JOYSTICK_SUPPORTED)
 #include "myjoystick.h"
 #endif
 
@@ -69,6 +68,17 @@ class CTEAEdit: public QPlainTextEdit
 
 public:
 
+  bool highlight_current_line;
+  bool hl_brackets;
+  bool draw_margin;
+  bool draw_linenums;
+  bool auto_indent;
+  bool spaces_instead_of_tabs;
+  int tab_sp_width; //in spaces
+  int brace_width; //in pixels
+  int margin_pos; //in chars
+  int margin_x;  //in pixels
+
   QString indent_val;
   QList <QTextEdit::ExtraSelection> extraSelections;
   QTextEdit::ExtraSelection brace_selection;
@@ -89,18 +99,6 @@ public:
 
   QWidget *lineNumberArea;
 
-  bool highlight_current_line;
-  bool hl_brackets;
-  bool draw_margin;
-  bool draw_linenums;
-
-  bool auto_indent;
-  bool spaces_instead_of_tabs;
-  int tab_sp_width; //in spaces
-  int brace_width; //in pixels
-  int margin_pos; //in chars
-  int margin_x;  //in pixels
-
 
   CTEAEdit (QWidget *parent = 0);
 
@@ -115,33 +113,29 @@ public:
 
   void indent();
   void un_indent();
+
   void calc_auto_indent();
   void setup_brace_width();
+  void braceHighlight();
+
+  void lineNumberAreaPaintEvent(QPaintEvent *event);
+  int lineNumberAreaWidth();
 
   void text_replace (const QString &s);
-
   void rect_sel_reset();
   void rect_sel_replace (const QString &s, bool insert = false);
   void update_ext_selections();
   void update_rect_sel();
   QString get_rect_sel();
   void rect_sel_cut (bool just_del = false);
-
-  void braceHighlight();
-
-  void lineNumberAreaPaintEvent(QPaintEvent *event);
-  int lineNumberAreaWidth();
-
   Q_INVOKABLE bool has_rect_selection();
 
 
 protected:
 
+  QMimeData* createMimeDataFromSelection();
   bool canInsertFromMimeData (const QMimeData *source);
   void insertFromMimeData (const QMimeData *source);
-
-  QMimeData* createMimeDataFromSelection();
-
   void paintEvent(QPaintEvent *event);
   void keyPressEvent (QKeyEvent *event);
   void resizeEvent(QResizeEvent *event);
@@ -151,7 +145,6 @@ public slots:
   void updateLineNumberAreaWidth (int newBlockCount);
   void cb_cursorPositionChanged();
   void updateLineNumberArea (const QRect &, int);
-
   void slot_selectionChanged();
 };
 
@@ -160,21 +153,19 @@ class CSyntaxHighlighter: public QSyntaxHighlighter
 {
 public:
 
-  CSyntaxHighlighter (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
-
   CDocument *document;
   bool casecare;
-
   int xml_format;
 
   QString exts;
   QString langs;
-
   QString cm_mult;
   QString cm_single;
 
   QTextCharFormat singleLineCommentFormat;
   QTextCharFormat multiLineCommentFormat;
+
+  CSyntaxHighlighter (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
 };
 
 
@@ -189,23 +180,23 @@ protected:
 public:
 
   struct HighlightingRule
-        {
-         QRegExp pattern;
-         QTextCharFormat format;
-        };
+         {
+          QRegExp pattern;
+          QTextCharFormat format;
+         };
 
   QRegExp commentStartExpression;
   QRegExp commentEndExpression;
 
   Qt::CaseSensitivity cs;
 
+  std::vector <HighlightingRule> highlightingRules;
+
   CSyntaxHighlighterQRegExp (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
-
-  QVector <HighlightingRule> highlightingRules;
-
   void load_from_xml (const QString &fname);
 };
 
+
 #if QT_VERSION >= 0x050000
 class CSyntaxHighlighterQRegularExpression: public CSyntaxHighlighter
 {
@@ -225,16 +216,14 @@ public:
 
   QRegularExpression commentStartExpression;
   QRegularExpression commentEndExpression;
-
   QRegularExpression::PatternOptions pattern_opts;
 
-  CSyntaxHighlighterQRegularExpression (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
-
-  QVector <HighlightingRule> highlightingRules;
-
   QTextCharFormat singleLineCommentFormat;
   QTextCharFormat multiLineCommentFormat;
 
+  std::vector <HighlightingRule> highlightingRules;
+
+  CSyntaxHighlighterQRegularExpression (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
   void load_from_xml (const QString &fname);
 };
 
@@ -249,8 +238,6 @@ public:
 
   bool cursor_xy_visible;
 
-  QHash <QString, QString> fnameswoexts;
-
   QString eol;
 
   CDox *holder;
@@ -314,35 +301,30 @@ public:
   QHash <QString, QString> markup_modes;
   QHash <QString, QString> hash_project;
 
+  std::vector <CDocument*> items;
+
   QLabel *l_status_bar;
   QLabel *l_charset;
-
-  QList <CDocument*> list;
-
   QStatusBar *status_bar;
   CLogMemo *log;
   QMainWindow *parent_wnd;
   QTabWidget *tab_widget;
+  QTabWidget *main_tab_widget;
   QMenu *recent_menu;
-
   QTimer *timer;
 
-
-
-
 #if defined(JOYSTICK_SUPPORTED)
 
   CJoystick *joystick;
 
   bool event (QEvent *ev);
   void handle_joystick_event (CJoystickAxisEvent *ev);
-#endif
 
+#endif
 
    CDox();
   ~CDox();
 
-
   void update_project (const QString &fileName);
   void reload_recent_list();
   void add_to_recent (CDocument *d);
@@ -356,12 +338,11 @@ public:
   Q_INVOKABLE CDocument* open_file_triplex (const QString &triplex);
   Q_INVOKABLE CDocument* get_document_by_fname (const QString &fileName);
   Q_INVOKABLE CDocument* get_current();
+
   Q_INVOKABLE void close_by_idx (int i);
   Q_INVOKABLE void close_current();
-
   Q_INVOKABLE void save_to_session (const QString &fileName);
   Q_INVOKABLE void load_from_session (const QString &fileName);
-
   Q_INVOKABLE void apply_settings();
   Q_INVOKABLE void apply_settings_single (CDocument *d);
 
@@ -374,11 +355,8 @@ public slots:
   void move_cursor_down();
   void move_cursor_left();
   void move_cursor_right();
-
-  void move_cursor_x(double v);
-  void move_cursor_y(double v);
-
-
+  void move_cursor_x (double v);
+  void move_cursor_y (double v);
 };
 
 
@@ -404,3 +382,4 @@ protected:
 };
 
 #endif
+
