@@ -1,5 +1,5 @@
  /**************************************************************************
- *   2007-2018 by Peter Semiletov                                          *
+ *   2007-2019 by Peter Semiletov                                          *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,7 +34,6 @@
 
 extern QSettings *settings;
 
-
 void CFMan::dir_up()
 {
   if (dir.path() == "/")
@@ -92,44 +91,16 @@ void CFMan::nav (const QString &path)
                                          QDir::Files | QDir::Drives,
                                          sort_flags);
 
-
-
-  /*QFileInfoList lst = dir.entryInfoList (QDir::Dirs | QDir::Hidden | QDir::NoDotAndDotDot |
-                                         QDir::Files | QDir::Drives,
-                                         QDir::Name |
-                                         QDir::DirsFirst | QDir::IgnoreCase | QDir::LocaleAware);
-
-  */
-  /*
-    QDir::Name   0x00  Sort by name.
-QDir::Time  0x01  Sort by time (modification time).
-QDir::Size  0x02  Sort by file size.
-QDir::Type  0x80  Sort by file type (extension).
-QDir::Unsorted 0x03  Do not sort.
-QDir::NoSort   -1 Not sorted by default.
-QDir::DirsFirst   0x04  Put the directories first, then the files.
-QDir::DirsLast 0x20  Put the files first, then the directories.
-QDir::Reversed 0x08  Reverse the sort order.
-QDir::IgnoreCase  0x10  Sort case-insensitively.
-QDir::LocaleAware 0x40  Sort items appropriately using the current locale settings.
-
-
-   */
-
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
-
   if (path != "/")
      append_dot_entry ("..");
-
 #else
-
   if (path.size() != 2)
      append_dot_entry ("..");
-
 #endif
 
-  foreach (QFileInfo fi, lst)
-           add_entry (fi);
+  for (int i = 0; i < lst.size(); i++)
+       add_entry (lst.at(i));
 
   setModel (mymodel);
   connect (selectionModel(), SIGNAL(currentChanged (const QModelIndex &, const QModelIndex &)), this, SLOT(cb_fman_currentChanged (const QModelIndex &, const QModelIndex &)));
@@ -177,8 +148,6 @@ void CFMan::tv_activated (const QModelIndex &index)
       QModelIndex index = mymodel->index (0, 0);
       selectionModel()->setCurrentIndex (index, QItemSelectionModel::Select |
                                          QItemSelectionModel::Rows);
-
-      return;
      }
   else
       emit file_activated (full_path);
@@ -235,7 +204,6 @@ void CFMan::append_dot_entry (const QString &fname)
 
 void CFMan::header_view_sortIndicatorChanged (int logicalIndex, Qt::SortOrder order)
 {
-//  qDebug() << "header col = " << logicalIndex << " order = " << order;
   sort_order = order;
   sort_mode = logicalIndex;
 
@@ -299,9 +267,7 @@ void CFMan::cb_fman_currentChanged (const QModelIndex &current, const QModelInde
      }
 
   QModelIndex i = model()->index (row, 0);
-
   QString item_string = i.data().toString();
-
   QString full_path = dir.path() + "/" + item_string;
 
   emit current_file_changed (full_path, item_string);
@@ -327,15 +293,16 @@ QStringList CFMan::get_sel_fnames()
   QModelIndexList il = selectionModel()->QItemSelectionModel::selectedRows (0);
   QStringList li;
 
-  foreach (QModelIndex index, il)
+  QList<QModelIndex>::iterator i;
+  for (i = il.begin(); i != il.end(); i++)
+      {
+       QString item_string = i->data().toString();
+       if (item_string != "..")
           {
-           QString item_string = index.data().toString();
-           if (item_string != "..")
-              {
-               QString full_path = dir.path() + "/" + item_string;
-               li.append (full_path);
-              }
+           QString full_path = dir.path() + "/" + item_string;
+           li.append (full_path);
           }
+      }
 
   return li;
 }
@@ -391,12 +358,12 @@ void CFMan::mouseMoveEvent (QMouseEvent *event)
   QDrag *drag = new QDrag (this);
   QMimeData *mimeData = new QMimeData;
 
-  QList <QUrl> list;
+  QList <QUrl> url_list;
 
-  foreach (QString fn, l)
-           list.append (QUrl::fromLocalFile (fn));
+  for (int i = 0; i < l.size(); i++)
+       url_list.append (QUrl::fromLocalFile (l[i]));
 
-  mimeData->setUrls (list);
+  mimeData->setUrls (url_list);
   drag->setMimeData (mimeData);
 
   if (drag->exec (Qt::CopyAction |
@@ -546,3 +513,4 @@ void CFMan::drawRow (QPainter *painter, const QStyleOptionViewItem &option, cons
   else
       QTreeView::drawRow (painter, option, index);
 }
+
