@@ -2,6 +2,7 @@
 this code is Public Domain
 */
 
+//NEED TO REFACTOR
 
 #include <QDebug>
 #include <QApplication>
@@ -15,9 +16,9 @@ this code is Public Domain
 #include <QSettings>
 
 #include "img_viewer.h"
-#include "exif.h"
-#include "utils.h"
+#include "exif_reader.h"
 
+#include "utils.h"
 
 extern QSettings *settings;
 
@@ -59,20 +60,18 @@ void CImgViewer::set_image_mini (const QString &fname)
 
 void CImgViewer::set_image_full (const QString &fname)
 {
- // window_full.show_image (fname);
   window_full.load_image (fname);
-  //qDebug() << "get_exif_orintation " << get_exif_orintation (fname);
 }
 
 
 QString CImgViewer::get_the_thumb_name (const QString &img_fname)
 {
- 
+
 //FIXME: add OS2 tweak!
 #if !defined(Q_OS_WIN) || !defined(Q_OS_OS2)
 
   QCryptographicHash h (QCryptographicHash::Md5); 
-  
+
   QString uri (img_fname);
   uri.prepend ("file://");
   h.addData (uri.toUtf8());
@@ -81,30 +80,30 @@ QString CImgViewer::get_the_thumb_name (const QString &img_fname)
   QString fname (QDir::homePath());
   fname.append ("/.thumbnails/large");
   fname.append ("/").append (digest).append (".png");
- 
+
   if (file_exists (fname))
      return fname;
-  
+
   fname.clear();
   fname.append (QDir::homePath());
   fname.append ("/.thumbnails/normal");
   fname.append ("/").append (digest).append (".png");
- 
+
   if (file_exists (fname))
      return fname;
-  
-#endif 
-  
+
+#endif
+
   return QString();
 }
 
 /*
 CViewerWindow::CViewerWindow (QWidget *parent): QWidget (parent)
 {
-  current_index = 0; 
+  current_index = 0;
   angle = 0.0;
   scale = 100;
-  
+
   img_full = new QLabel (tr ("preview"));
   img_full->setAlignment (Qt::AlignCenter);
   QVBoxLayout *lt = new QVBoxLayout;
@@ -378,8 +377,6 @@ void CZORWindow::load_image (const QString &fname)
 {
   if (! file_exists (fname))
      return;
-
- // qDebug() << "CZORWindow::load_image " << fname;
  
   if (! source_image.load (fname))
      qDebug() << "cannot load " << fname;
@@ -387,10 +384,24 @@ void CZORWindow::load_image (const QString &fname)
   fname_image = fname;
   
   bool orientation_portrait = false; 
-  
+
   int exif_orientation = get_exif_orientation (fname);
- // qDebug() << "exif_orientation: " << exif_orientation;
+
+
+/*
+  easyexif::EXIFInfo ei;
+  QByteArray b = file_load (fname);
+  ei.parseFrom ((unsigned char *)b.data(), b.length());
+
   
+  int exif_orientation = ei.Orientation;//get_exif_orientation (fname);
+  */
+
+  //qDebug() << "exif_orientation: " << exif_orientation;
+//  qDebug() << "ei: " << ei.Orientation;
+ // std::cout << ei.Make;
+
+
   if (settings->value ("zor_use_exif_orientation", 0).toInt())
       if (exif_orientation == 6 || exif_orientation == 8)
           orientation_portrait = true;
@@ -419,14 +430,14 @@ void CZORWindow::load_image (const QString &fname)
      {
       QTransform transform;
       
-      qreal angle;
+      qreal angle = 0.0;
       
       if (exif_orientation == 6)
          angle = 90;
-      else   
+      else
       if (exif_orientation == 8) //make clockwise
          angle = 270;
-      
+         
       transform.rotate (angle);
       
       QImage transformed_image = source_image.transformed (transform);
@@ -468,7 +479,6 @@ void CZORWindow::keyPressEvent (QKeyEvent * event)
 }
 
 
-
 void CGIFWindow::keyPressEvent (QKeyEvent * event)
 {
   if (event->key() == Qt::Key_Escape)
@@ -518,3 +528,4 @@ void CGIFWindow::closeEvent (QCloseEvent *event)
 {
   event->accept();
 }
+
