@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyleft 2007-2018 by Peter Semiletov <peter.semiletov@gmail.com>     *
+ *   Copyleft 2007-2019 by Peter Semiletov <peter.semiletov@gmail.com>     *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,6 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include <cstring>
 
 #include <QApplication>
 #include <QDebug>
@@ -56,7 +57,7 @@ int main (int argc, char *argv[])
       if (argc > 1)
          for (int i = 1; i < argc; i++) 
               app.sendMessage (QString(argv[i]));
-       return 0;
+      return 0;
      }
 
 #endif
@@ -65,14 +66,21 @@ int main (int argc, char *argv[])
 
  CSingleApplicationShared app (argc, argv, "tea unique id 1977");
  
- if (app.alreadyExists())
-    {
-     if (argc > 1)
-        for (int i = 1; i < argc; i++) 
-             app.sendMessage (QString(argv[i]));
+ bool single_mode = true;
+ 
+  if (argc > 1)
+     if (strcmp(argv[1], "--m") == 0)
+        single_mode = false;
+    
+    
+  if (single_mode && app.alreadyExists())
+     {
+      if (argc > 1)
+         for (int i = 1; i < argc; i++) 
+              app.sendMessage (QString(argv[i]));
              
-     return 0;
-    }
+      return 0;
+     }
     
 #endif     
     
@@ -95,3 +103,4 @@ int main (int argc, char *argv[])
   
   return app.exec();   
 }
+
