@@ -1,5 +1,5 @@
 /**************************************************************************
- *   2007-2018 by Peter Semiletov                            *
+ *   2007-2019 by Peter Semiletov                            *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,13 +22,11 @@
 #ifndef RVLN_H
 #define RVLN_H
 
-
 #include <QListWidget>
 #include <QComboBox>
 #include <QProgressBar>
 #include <QCheckBox>
 #include <QSpinBox>
-#include <QFontComboBox>
 #include <QSessionManager>
 #include <QApplication>
 #include <QCoreApplication>
@@ -57,9 +55,7 @@
 #include "img_viewer.h"
 
 
-//#ifdef SPELLCHECK_ENABLE
 #include "spellchecker.h"
-//#endif
 
 
 
@@ -72,31 +68,31 @@ public:
 
 
   int styleHint (StyleHint hint, const QStyleOption *option = 0,
-                 const QWidget *widget = 0, QStyleHintReturn *returnData = 0) const 
+                 const QWidget *widget = 0, QStyleHintReturn *returnData = 0) const
                 {
                  if (hint == QStyle::SH_ItemView_ActivateItemOnSingleClick)
                     return 0;
-         
+
                  if (! b_altmenu && hint == QStyle::SH_MenuBar_AltKeyNavigation)
                     return 0;
-                  
+
                  return QProxyStyle::styleHint (hint, option, widget, returnData);
                 }
-     
+
    MyProxyStyle (QStyle *style = 0);
 };
 
 
-
 #if QT_VERSION >= 0x050000
+//#if QT_VERSION_MAJOR >= 5
 class QStyleHints
 {
 public:
-  int cursorFlashTime() const 
-     {
-      return MyProxyStyle::cursor_blink_time;	
-     } 
 
+  int cursorFlashTime() const
+      {
+       return MyProxyStyle::cursor_blink_time;
+      }
 };
 #endif
 
@@ -105,14 +101,14 @@ public:
 class CQQuickWindow: public QQuickWindow
 {
 Q_OBJECT
-   
+
 public:
 
   QString id;
- 
+
   CQQuickWindow (QWindow *parent = 0): QQuickWindow (parent) {}
   ~CQQuickWindow() {}
- 
+
 protected:
 
   bool event (QEvent *event);
@@ -127,9 +123,8 @@ public:
 
   QString id;
   CQQuickWindow *window;
- 
+
   CPluginListItem (const QString &plid, CQQuickWindow *wnd);
-//  ~CPluginListItem() {}
 };
 #endif
 
@@ -167,9 +162,9 @@ public:
 
   QString string_value;
   int int_value;
-   
+
   CStrIntPair (const QString &s, int i);
-};  
+};
 
 
 class CDarkerWindow: public QWidget
@@ -177,7 +172,7 @@ class CDarkerWindow: public QWidget
 Q_OBJECT
 
   QSlider *slider;
-  
+
 public:
 
   CDarkerWindow();
@@ -185,9 +180,9 @@ public:
 protected:
 
   void closeEvent (QCloseEvent *event);
-  
+
 public slots:
- 
+
  void slot_valueChanged (int value);
 };
 
@@ -195,7 +190,7 @@ public slots:
 class CAboutWindow: public QWidget
 {
 Q_OBJECT
-  
+
 public:
 
   QLabel *logo;
@@ -205,7 +200,7 @@ public:
 protected:
 
   void closeEvent (QCloseEvent *event);
-  
+
 public slots:
 
   void update_image();
@@ -219,8 +214,9 @@ Q_OBJECT
 public:
 
   QListWidget *list;
-  
+
   CTextListWnd (const QString &title, const QString &label_text);
+  ~CTextListWnd();
 
 protected:
 
@@ -235,20 +231,20 @@ Q_OBJECT
 public:
 
   rvln();
-  ~rvln() {}
-  
+  ~rvln();
+
 #ifdef USE_QML_STUFF
   QQmlEngine *qml_engine;
 #endif
-  
-  
+
+
   QStringList sl_places_bmx;
   QStringList sl_urls;
   QStringList sl_charsets;
   QStringList sl_last_used_charsets;
   QStringList sl_fif_history;
-  
-  int fm_entry_mode; 
+
+  int fm_entry_mode;
 
   QDate date1;
   QDate date2;
@@ -257,21 +253,16 @@ public:
 
   CLogMemo *log;
   QAction *last_action;
- 
- 
+
+
   CShortcuts *shortcuts;
   CFMan *fman;
   CImgViewer *img_viewer;
 
-//#ifdef SPELLCHECK_ENABLE
-
   CSpellchecker *spellchecker;
   QStringList spellcheckers;
   QString cur_spellchecker;
 
-//#endif
-
-  
   int icon_size;
 
   bool b_preview;
@@ -284,14 +275,14 @@ public:
   int idx_tab_learn;
   int idx_tab_keyboard;
   int idx_prev;
- 
+
   int fman_find_idx;
   QList <QStandardItem *> l_fman_find;
-  
+
   bool ui_update;
 
   QString fname_storage_file;
-  QString fname_stylesheet; 
+  QString fname_stylesheet;
   QString man_search_value;
   QString markup_mode;
 
@@ -299,13 +290,13 @@ public:
   QHash <QString, QString> programs;
   QHash <QString, QString> places_bookmarks;
   QHash <int, QString> moon_phase_algos;
-  
+
   QTranslator myappTranslator;
   QTranslator qtTranslator;
 
   QDir dir_lv;
 
- 
+
 #ifdef PRINTER_ENABLE
   QPrinter printer;
 #endif
@@ -315,7 +306,7 @@ public:
   QString fman_fname_to_find;
 
   QString dir_user_dict;
-  QString dir_profiles;  
+  QString dir_profiles;
   QString dir_last;
   QString dir_config;
   QString dir_templates;
@@ -323,13 +314,9 @@ public:
   QString dir_hls;
   QString dir_themes;
 
-
-//#if QT_VERSION >= 0x050000
-
   QString dir_plugins;
 
-//#endif
-  
+
   QString dir_snippets;
   QString dir_scripts;
   QString dir_palettes;
@@ -361,21 +348,17 @@ public:
   QProgressBar *pb_status;
   QLineEdit *ed_spellcheck_path;
   QLineEdit *ed_aspellcheck_path;
-  
+
   QCheckBox *cb_use_qregexpsyntaxhl;
 
-//#if !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD)
-//#if defined(Q_OS_LINUX) || defined(Q_WS_X11)
 #if defined(JOYSTICK_SUPPORTED)
-
   QCheckBox *cb_use_joystick;
-//#endif
 #endif
 
   QCheckBox *cb_right_to_left;
 
   QCheckBox *cb_wordwrap;
-  
+
   QCheckBox *cb_fif_at_toolbar;
   QCheckBox *cb_show_linenums;
   QCheckBox *cb_hl_current_line;
@@ -399,10 +382,10 @@ public:
 
   QSpinBox *spb_tab_sp_width;
   QCheckBox *cb_center_on_cursor;
-  
+
   QCheckBox *cb_full_path_at_window_title;
-  
-  
+
+
   QCheckBox *cb_use_trad_dialogs;
   QCheckBox *cb_start_on_sunday;
   QCheckBox *cb_northern_hemisphere;
@@ -439,20 +422,50 @@ main window callbacks
 
   void receiveMessage (const QString &msg);
   void receiveMessageShared (const QStringList& msg);
-        
+
   void view_use_theme();
 
   void select_label();
   void update_labels_menu();
   void update_labels_list();
 
-  
+
   void fm_full_info();
 
   void fm_hashsum_md5();
   void fm_hashsum_md4();
   void fm_hashsum_sha1();
 
+
+#if QT_VERSION >= 0x050000
+
+  void fm_hashsum_sha224();
+  void fm_hashsum_sha384();
+  void fm_hashsum_sha256();
+  void fm_hashsum_sha512();
+
+
+#endif
+
+
+//#if (QT_VERSION_MAJOR >= 5 && QT_VERSION_MINOR >= 1)
+
+  void fm_hashsum_sha3_224();
+  void fm_hashsum_sha3_256();
+  void fm_hashsum_sha3_384();
+  void fm_hashsum_sha3_512();
+
+//#endif
+
+
+  void fm_hashsum_keccak_256();
+  void fm_hashsum_keccak_224();
+  void fm_hashsum_keccak_384();
+  void fm_hashsum_keccak_512();
+
+
+
+
   void fman_unpack_zip();
   void fman_zip_info();
 
@@ -464,7 +477,7 @@ main window callbacks
   void fman_multreplace();
   void fman_apply_template();
 
-  
+
   void fman_drives_changed (const QString & path);
   void fman_current_file_changed (const QString &full_path, const QString &just_name);
   void fman_file_activated (const QString &full_path);
@@ -486,9 +499,7 @@ main window callbacks
 //  void tab_options_pageChanged (int index);
 
 #ifdef PRINTER_ENABLE
-
   void file_print();
-
 #endif
 
 
@@ -498,7 +509,7 @@ main window callbacks
   void rename_selected();
 
   void file_reload();
-  void file_reload_enc_itemDoubleClicked (QListWidgetItem *item); 
+  void file_reload_enc_itemDoubleClicked (QListWidgetItem *item);
   void file_reload_enc();
   void file_open_bookmarks_file();
   void file_open_programs_file();
@@ -510,9 +521,9 @@ main window callbacks
   void file_open_program();
   void file_add_to_bookmarks();
   void file_crapbook();
-  
+
   void file_notes();
-  
+
   void file_use_template();
   void file_use_snippet();
   void file_use_palette();
@@ -536,7 +547,9 @@ main window callbacks
 
   void cal_remove();
   void fn_sum_by_last_col();
-  
+
+  void fn_anagram();
+
   void fn_insert_cpp();
   void fn_insert_c();
   void fn_insert_template_html5();
@@ -572,7 +585,7 @@ main window callbacks
   void set_as_storage_file();
   void copy_to_storage_file();
   void capture_clipboard_to_storage_file();
-  
+
   void upCase();
   void dnCase();
 
@@ -588,7 +601,7 @@ main window callbacks
   void ide_global_definition();
   void ide_global_references();
 */
-  
+
   void fn_count();
   void fn_count_rx();
 
@@ -609,21 +622,21 @@ main window callbacks
   void fn_table_swap_cells();
   void fn_table_delete_cells();
   void fn_table_copy_cells();
-  
+
   void fn_flip_a_list();
   void fn_flip_a_list_sep();
-  
+
   void fn_insert_loremipsum();
   void fn_insert_template_html();
   void fn_run_script();
   void cb_script_finished (int exitCode, QProcess::ExitStatus exitStatus);
   void fn_number_arabic_to_roman();
   void fn_number_roman_to_arabic();
-  
+
   void fn_number_dms2dc();
   void fn_number_dd2dms();
 
-  
+
   void fn_filter_rm_less_than();
   void fn_filter_rm_greater_than();
   void fn_filter_rm_duplicates();
@@ -633,20 +646,20 @@ main window callbacks
   void fn_filter_delete_after_sep();
 
   void fn_rm_formatting();
-  
+
   void fn_rm_compress();
- 
+
   void text_compare_two_strings();
-  
+
   void fn_convert_quotes_angle();
   void fn_convert_quotes_curly();
-  
+
   void fn_convert_quotes_tex_curly();
 
   void fn_convert_quotes_tex_angle_01();
   void fn_convert_quotes_tex_angle_02();
-  
-  
+
+
   void fn_get_words_count();
   void fn_unitaz_abc();
   void fn_extract_words();
@@ -663,9 +676,9 @@ main window callbacks
   void fn_number_decimal_to_binary();
   void fn_number_flip_bits();
   void fn_binary_to_decimal();
-  
+
   void remove_formatting();
-  
+
 #if defined (HUNSPELL_ENABLE) || defined (ASPELL_ENABLE)
 
   void fn_change_spell_lang();
@@ -686,7 +699,7 @@ main window callbacks
 #endif
 #endif
 
-#endif // SPELLCHECKERS ENABLED 
+#endif // SPELLCHECKERS ENABLED
 
   void scale_image();
 
@@ -710,12 +723,12 @@ main window callbacks
   void mrkup_mode_choosed();
   void mrkup_header();
   void mrkup_align();
-  
+
   void mrkup_align_center();
   void mrkup_align_left();
   void mrkup_align_right();
   void mrkup_align_justify();
-  
+
   void mrkup_document_weight();
   void markup_ins_image();
   void mrkup_color();
@@ -738,8 +751,8 @@ main window callbacks
   void view_toggle_fs();
   void view_stay_on_top();
   void instr_font_gallery();
-  
-  
+
+
   void nav_goto_line();
   void nav_goto_right_tab();
   void nav_goto_left_tab();
@@ -784,7 +797,7 @@ main window callbacks
   void set_eol_mac();
 
   void fn_stat_words_lengths();
-  
+
   void guess_enc();
 
   void cal_add_days();
@@ -792,17 +805,14 @@ main window callbacks
   void cal_add_years();
 
   void recentoff();
-  
+
 
 /*************************
 prefs window callbacks
 *************************/
-//#if !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD) && !defined(Q_OS_FREEBSD)
 
-//#if defined(Q_OS_LINUX) || defined(Q_WS_X11)
 #if defined(JOYSTICK_SUPPORTED)
   void cb_use_joystick_stateChanged (int state);
-//#endif
 #endif
 
 //  void cmb_ui_langs_currentIndexChanged (const QString &text);
@@ -819,22 +829,29 @@ prefs window callbacks
   void pb_remove_hotkey_clicked();
 
   void slot_lv_menuitems_currentItemChanged (QListWidgetItem *current, QListWidgetItem *previous);
-  void slot_app_fontname_changed (const QString &text);
-  void slot_editor_fontname_changed (const QString &text);
-  void slot_font_size_changed (int i);
+  
+ // void slot_app_fontname_changed (const QString &text);
+//  void slot_editor_fontname_changed (const QString &text);
+ // void slot_font_size_changed (int i);
 
-  void slot_logmemo_fontname_changed (const QString &text);
-  void slot_logmemo_font_size_changed (int i);
+//  void slot_logmemo_fontname_changed (const QString &text);
+//  void slot_logmemo_font_size_changed (int i);
+
+  void slot_font_logmemo_select();
+  void slot_font_interface_select();
+  void slot_font_editor_select();
 
 
-  void slot_app_font_size_changed (int i);
+//  void slot_app_font_size_changed (int i);
+
   void slot_style_currentIndexChanged (const QString &text);
 
-  
+
 #ifdef USE_QML_STUFF
   void fn_use_plugin();
+
 #endif
-  
+
 public:
 
 /*************************
@@ -879,8 +896,8 @@ main window widgets
 
   QMenu *menu_fn_sessions;
   QMenu *menu_fn_scripts;
-  
-  
+
+
 #ifdef USE_QML_STUFF
   QMenu *menu_fn_plugins;
 #endif
@@ -903,6 +920,8 @@ main window widgets
   QMenu *menu_fm_file_infos;
   QMenu *menu_fm_img_conv;
   QMenu *menu_fm_zip;
+  QMenu *menu_fm_checksums;
+
   QMenu *menu_view;
   QMenu *menu_spell_langs;
   QMenu *helpMenu;
@@ -920,7 +939,7 @@ main window widgets
 
   QAction *act_test;
   QAction *filesAct;
-  
+
   QAction *newAct;
   QAction *openAct;
   QAction *saveAct;
@@ -936,7 +955,7 @@ main window widgets
   QAction *aboutQtAct;
   QAction *menu_find_whole_words;
   QAction *menu_find_from_cursor;
-  
+
   QAction *menu_find_case;
   QAction *menu_find_regexp;
   QAction *menu_find_fuzzy;
@@ -951,7 +970,7 @@ main window widgets
   QComboBox *cmb_styles;
   QComboBox *cmb_icon_size;
 
-  
+
   CCalendarWidget *calendar;
 
 /*************************
@@ -970,22 +989,22 @@ prefs window widgets
 
   QLineEdit *ed_locale_override;
   QLineEdit *ed_img_viewer_override;
-  
+
   QSpinBox *spb_cursor_blink_time;
   QSpinBox *spb_cursor_width;
-  
+
   CShortcutEntry *ent_shtcut;
   QListWidget *lv_menuitems;
 
-  QFontComboBox *cmb_font_name;
-  QSpinBox *spb_font_size;
+//  QFontComboBox *cmb_font_name;
+//  QSpinBox *spb_font_size;
 
-  QFontComboBox *cmb_logmemo_font_name;
-  QSpinBox *spb_logmemo_font_size;
+//  QFontComboBox *cmb_logmemo_font_name;
+//  QSpinBox *spb_logmemo_font_size;
 
 
-  QFontComboBox *cmb_app_font_name;
-  QSpinBox *spb_app_font_size;
+//  QFontComboBox *cmb_app_font_name;
+//  QSpinBox *spb_app_font_size;
 
   QLineEdit *ed_fman_path;
   QListWidget *lv_places;
@@ -993,16 +1012,17 @@ prefs window widgets
 
   QCheckBox *cb_altmenu;
   QCheckBox *cb_wasd;
-  
+
 
   QCheckBox *cb_auto_img_preview;
   QCheckBox *cb_override_locale;
 
   QCheckBox *cb_override_img_viewer;
+  QCheckBox *cb_use_enca_for_charset_detection;
 
   QComboBox *cmb_cmdline_default_charset;
-  
-  
+
+
   QComboBox *cmb_zip_charset_in;
   QComboBox *cmb_zip_charset_out;
 
@@ -1017,19 +1037,18 @@ prefs window widgets
 
 
   void update_stylesheet (const QString &f);
-  
+
   QString theme_dir;
-  
+
   QIcon get_theme_icon (const QString &name);
   QString get_theme_icon_fname (const QString &name);
 
   void update_dyn_menus();
   void create_paths();
-  
+
   void calendar_update();
 
 
-//#ifdef SPELLCHECK_ENABLE
 #if defined (HUNSPELL_ENABLE) || defined (ASPELL_ENABLE)
   void setup_spellcheckers();
   void create_spellcheck_menu();
@@ -1055,14 +1074,14 @@ prefs window widgets
   void update_sessions();
   void update_palettes();
   void update_view_hls();
-  
+
 #ifdef USE_QML_STUFF
   void update_plugins();
 #endif
-  
+
   void update_themes();
 
-  
+
   //void update_hls (bool force = false);
   void update_hls_noncached();
 
@@ -1077,7 +1096,7 @@ prefs window widgets
 
 
   void createToolBars();
-  void createStatusBar();
+//  void createStatusBar();
   void readSettings();
   void writeSettings();
 
@@ -1090,36 +1109,35 @@ prefs window widgets
 
   void createFman();
   void create_markup_hash();
-  //void create_markup_hash2();
 
   void count_substring (bool use_regexp);
 
   void run_unitaz (int mode);
- 
+
   void create_moon_phase_algos();
 
- 
+
   QHash <QString, QString> load_eclipse_theme_xml (const QString &fname);
 
   void load_palette (const QString &fileName);
 
- 
+
   QTextDocument::FindFlags get_search_options();
 
   void fman_convert_images (bool by_side, int value);
- 
+
   Q_INVOKABLE QString fif_get_text();
-   
-  
+
+
   void fn_filter_delete_by_sep (bool mode);
- 
+
   void fman_items_select_by_regexp (bool mode);
   void fman_find();
   void fman_find_next();
   void fman_find_prev();
- 
+
   void opt_update_keyb();
-  
+
   void opt_shortcuts_find();
   void opt_shortcuts_find_next();
   void opt_shortcuts_find_prev();
@@ -1129,11 +1147,11 @@ prefs window widgets
   void idx_tab_tune_activate();
   void idx_tab_fman_activate();
   void idx_tab_learn_activate();
-  
+
 #ifdef USE_QML_STUFF
   void plugins_init();
   void plugins_done();
-#endif  
+#endif
 
   void markup_text (const QString &mode);
 };
