@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyleft 2007-2018 by Peter Semiletov                                 *
+ *   Copyleft 2007-2019 by Peter Semiletov                                 *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,19 +19,18 @@
  ***************************************************************************/
 
 
-#include "shortcuts.h"
-#include "utils.h"
-#include "gui_utils.h"
-
 #include <QString>
 #include <QDebug>
 
-
 #include <QKeyEvent>
 #include <QAction>
 #include <QStringList>
 #include <QKeySequence>
 
+#include "shortcuts.h"
+#include "utils.h"
+#include "gui_utils.h"
+
 
 
 QString mod_to_string (Qt::KeyboardModifiers k)
@@ -129,14 +128,11 @@ void CShortcuts::captions_iterate()
 {
   captions.clear();
   QList <QAction *> a = w->findChildren <QAction *>();
-    
-  foreach (QAction *ac, a)  
-          if (ac)
-          if (! ac->text().isEmpty())
-             {
-              captions.prepend (ac->text());
-             // qDebug() << ac->text();
-             }
+
+  for (int i = 0; i < a.size(); i++) 
+      if (a.at(i))
+          if (! a.at(i)->text().isEmpty())
+              captions.prepend (a.at(i)->text());
 
   captions.sort();
   captions.removeDuplicates(); //nasty hack
@@ -146,11 +142,11 @@ void CShortcuts::captions_iterate()
 QAction* CShortcuts::find_by_caption (const QString &text)
 {
   QList<QAction *> a = w->findChildren<QAction *>();
-  
-  foreach (QAction *ac, a)  
-          if (ac->text() == text)
-             return ac;
- 
+
+  for (int i = 0; i < a.size(); i++) 
+       if (a.at(i)->text() == text)
+          return a.at(i);
+
   return NULL;
 }
 
@@ -159,10 +155,10 @@ QAction* CShortcuts::find_by_shortcut (const QString &shcut)
 {
   QList<QAction *> a = w->findChildren<QAction *>();
 
-  foreach (QAction *ac, a)  
-         if (ac->shortcut().toString() == shcut)
-            return ac;
-  
+  for (int i = 0; i < a.size(); i++) 
+       if (a.at(i)->shortcut().toString() == shcut)
+          return a.at(i);
+
   return NULL;
 }
 
@@ -195,10 +191,10 @@ void CShortcuts::save_to_file (const QString &file_name)
   QList<QAction *> a = w->findChildren<QAction *>();
   QString s;
 
-  foreach (QAction *ac, a)
-          if (! ac->shortcut().toString().isEmpty())
-             s.append (ac->text()).append ("=").append (ac->shortcut().toString()).append ("\n");
-                 
+   for (int i = 0; i < a.size(); i++) 
+       if (! a.at(i)->shortcut().toString().isEmpty())
+           s.append (a.at(i)->text()).append ("=").append (a.at(i)->shortcut().toString()).append ("\n");
+
   qstring_save (file_name, s);
 }
 
@@ -212,12 +208,9 @@ void CShortcuts::load_from_file (const QString &file_name)
 
   QList<QAction *> a = w->findChildren<QAction *>();
 
-  foreach (QAction *ac, a)
-          if (hash.contains (ac->text()))
-             {
-              //if (ac->shortcut().isEmpty())
-              ac->setShortcut (QKeySequence (hash.value (ac->text())));
-             }
+  for (int i = 0; i < a.size(); i++) 
+      if (hash.contains (a.at(i)->text()))
+         a[i]->setShortcut (QKeySequence (hash.value (a.at(i)->text())));
 }
 
 
