@@ -34,6 +34,7 @@ some code is taken from Scribus::util.cpp:
 */
 
 
+#include <algorithm>
 
 #include <QString>
 #include <QMap>
@@ -42,6 +43,8 @@ some code is taken from Scribus::util.cpp:
 #include "textproc.h"
 #include "utils.h"
 
+using namespace std;
+
 
 int str_fuzzy_search (const QString &s, const QString &text_to_find, int start_pos, double q)
 {
@@ -287,9 +290,9 @@ int value (char c)
 
 int romanToDecimal (const char *roman)
 {
-   int decimal = 0;
-   for (; *roman; roman++)
-   {
+  int decimal = 0;
+  for (; *roman; roman++)
+      {
       /* Check for four of a letter in a fow */
       if ((*(roman + 1) && *(roman + 2) && *(roman + 3))
          && (*roman == *(roman + 1))
@@ -378,8 +381,8 @@ QString qstringlist_process (const QString &s, const QString &params, int mode)
                                            QStringList sl = s.split (params);
                                            sl.sort();
 
-                                           foreach (QString t, sl)
-                                           l.prepend (t);
+                                           for (int i = 0; i < sl.size(); i++)
+                                                l.prepend (sl.at(i));
 
                                            result = l.join (params);
                                            return result;
@@ -390,37 +393,40 @@ QString qstringlist_process (const QString &s, const QString &params, int mode)
                                                  {
                                                   QMap <QString, QString> map;
 
-                                                  foreach (QString value, sl)
-                                                          map.insert (value.toLower(), value);
-
-                                                  foreach (QString value, map)
-                                                         l.append (value);
+                                                  for (int i = 0; i < sl.size(); i++)
+                                                      map.insert (sl[i].toLower(), sl[i]);
+                     
+                                                  for (QMap<QString, QString>::const_iterator i = map.constBegin();
+                                                       i != map.constEnd();
+                                                       i++)
+                                                       l.append (i.value());
 
                                                   break;
                                                  }
 
           case QSTRL_PROC_FLT_REMOVE_EMPTY:
                                            {
-                                            foreach (QString s, sl)
-                                                    if (! s.isEmpty())
-                                                       l.append (s);
+                                            for (QList <QString>::iterator i = sl.begin(); i != sl.end(); i++)
+                                                if (! i->isEmpty())
+                                                   l.append (*i);
+
                                             break;
                                            };
 
 
           case QSTRL_PROC_FLT_REMOVE_DUPS:
                                           {
-                                           foreach (QString s, sl)
-                                                    if (! l.contains (s))
-                                                        l.append (s);
+                                           for (QList <QString>::iterator i = sl.begin(); i != sl.end(); i++)
+                                               if (! l.contains (*i))
+                                                  l.append (*i);
                                            break;
                                           };
 
           case QSTRL_PROC_REMOVE_FORMATTING:
                                            {
-                                            foreach (QString t, sl)
-                                                     l.append (t.simplified());
-
+                                            for (QList <QString>::iterator i = sl.begin(); i != sl.end(); i++)
+                                                 l.append (i->simplified());
+                                           
                                             break;
                                            };
 
@@ -440,26 +446,31 @@ QString qstringlist_process (const QString &s, const QString &params, int mode)
 
            case QSTRL_PROC_LIST_FLIP:
                                      {
-                                      foreach (QString t, sl)
-                                              l.prepend (t);
+                                      for (QList <QString>::iterator i = sl.begin(); i != sl.end(); i++)
+                                           l.prepend (*i);
+
                                       break;
                                      }
 
            case QSTRL_PROC_FLT_LESS:
                                     {
                                      int t = params.toInt();
-                                     foreach (QString s, sl)
-                                     if (s.size() > t)
-                                        l.append (s);
+
+                                     for (QList <QString>::iterator i = sl.begin(); i != sl.end(); i++)
+                                          if (i->size() > t)
+                                             l.append (*i);
+
                                      break;
                                     }
 
            case QSTRL_PROC_FLT_GREATER:
                                     {
                                      int t = params.toInt();
-                                     foreach (QString s, sl)
-                                     if (s.size() < t)
-                                        l.append (s);
+
+                                     for (QList <QString>::iterator i = sl.begin(); i != sl.end(); i++)
+                                          if (i->size() < t)
+                                             l.append (*i);
+
                                      break;
                                     }
          }
@@ -534,19 +545,10 @@ unsigned int bin_to_decimal (const QString &s)
 
 
 QString conv_quotes (const QString &source, const QString &c1, const QString &c2)
-//QString conv_quotes (const QString &source, bool tex_mode)
 {
-//  QString c1 = "\xAB";
-//  QString c2 = "\xBB";
   QString x;
   QString dest;
-/*
-  if (tex_mode)
-    {
-     c1 = "``";
-     c2 = "\'\'";
-    }
-  */
+
   bool flag = true;
   int c = source.size() - 1;
   for (int i = 0; i <= c; i++)
@@ -621,3 +623,19 @@ QStringList html_get_by_patt (const QString &s, const QString &spatt)
 
   return result;
 }
+
+
+QStringList anagram (const QString &s)
+{
+  QString input = s;
+  QStringList sl;
+
+  sort (input.begin(), input.end());
+
+  do
+    sl.append (input);
+  while (next_permutation (input.begin(), input.end()));
+
+  return sl;
+}
+
