@@ -1,6 +1,5 @@
 /*
-
-DJVU read code taken fromdvutxt.c:  
+DJVU read code taken fromdvutxt.c:
 
 //C- DjVuLibre-3.5
 //C- Copyright (c) 2002  Leon Bottou and Yann Le Cun.
@@ -26,16 +25,16 @@ DJVU read code taken fromdvutxt.c:
 //C- | The computer code originally released by LizardTech under this
 //C- | license and unmodified by other parties is deemed "the LIZARDTECH
 //C- | ORIGINAL CODE."  Subject to any third party intellectual property
-//C- | claims, LizardTech grants recipient a worldwide, royalty-free, 
-//C- | non-exclusive license to make, use, sell, or otherwise dispose of 
-//C- | the LIZARDTECH ORIGINAL CODE or of programs derived from the 
-//C- | LIZARDTECH ORIGINAL CODE in compliance with the terms of the GNU 
-//C- | General Public License.   This grant only confers the right to 
-//C- | infringe patent claims underlying the LIZARDTECH ORIGINAL CODE to 
-//C- | the extent such infringement is reasonably necessary to enable 
-//C- | recipient to make, have made, practice, sell, or otherwise dispose 
-//C- | of the LIZARDTECH ORIGINAL CODE (or portions thereof) and not to 
-//C- | any greater extent that may be necessary to utilize further 
+//C- | claims, LizardTech grants recipient a worldwide, royalty-free,
+//C- | non-exclusive license to make, use, sell, or otherwise dispose of
+//C- | the LIZARDTECH ORIGINAL CODE or of programs derived from the
+//C- | LIZARDTECH ORIGINAL CODE in compliance with the terms of the GNU
+//C- | General Public License.   This grant only confers the right to
+//C- | infringe patent claims underlying the LIZARDTECH ORIGINAL CODE to
+//C- | the extent such infringement is reasonably necessary to enable
+//C- | recipient to make, have made, practice, sell, or otherwise dispose
+//C- | of the LIZARDTECH ORIGINAL CODE (or portions thereof) and not to
+//C- | any greater extent that may be necessary to utilize further
 //C- | modifications or combinations.
 //C- |
 //C- | The LIZARDTECH ORIGINAL CODE is provided "AS IS" WITHOUT WARRANTY
@@ -45,18 +44,22 @@ DJVU read code taken fromdvutxt.c:
 //C- +------------------------------------------------------------------
 */
 
+#include <iostream>
+
 #include <QXmlStreamReader>
 #include <QTextStream>
 #include <QDebug>
-#include <iostream>
+
 
 //FIXME: not good with cmake, cmake just use Qt5 here
 #if defined (POPPLER_ENABLE) || defined(Q_OS_OS2)
-#if QT_VERSION >= 0x050000
+
+#if QT_VERSION_MAJOR >= 5
 #include <poppler-qt5.h>
 #else
 #include <poppler-qt4.h>
 #endif
+
 #endif
 
 
@@ -79,6 +82,8 @@ DJVU read code taken fromdvutxt.c:
 #include "textproc.h"
 
 
+using namespace std;
+
 QString extract_text_from_xml (const QString &string_data, const QStringList &tags)
 {
   QString data;
@@ -92,14 +97,14 @@ QString extract_text_from_xml (const QString &string_data, const QStringList &ta
 
          QString tag_name = xml.qualifiedName().toString().toLower();
 
-         foreach (QString ts, tags)
-                {
-                 if (xml.isStartElement() && tag_name == ts)
-                    tt = true;
+         for (QList <QString>::const_iterator ts = tags.begin(); ts != tags.end(); ts++)
+             {
+              if (xml.isStartElement() && tag_name == *ts)
+                  tt = true;
 
-                 if (xml.isEndElement() && tag_name == ts) 
-                    tt = false; 
-                 }
+              if (xml.isEndElement() && tag_name == *ts)
+                  tt = false;
+             }
 
          if (tt && xml.isCharacters())
             {
@@ -155,7 +160,7 @@ bool CTioPlainText::load (const QString &fname)
 
   QFile file (fname);
 
-  if (! file.open (QFile::ReadOnly/* | QFile::Text)*/))
+  if (! file.open (QFile::ReadOnly))
      {
       error_string = file.errorString();
       return false;
@@ -196,31 +201,30 @@ CTioHandler::CTioHandler()
 {
   default_handler = new CTioPlainText;
 
-  list.append (default_handler);
-  list.append (new CTioGzip);
-  list.append (new CTioXMLZipped);
-  list.append (new CTioODT);
-  list.append (new CTioABW);
-  list.append (new CTioFB2);
-  list.append (new CTioRTF);
-  list.append (new CTioEpub);
+  list.push_back (default_handler);
+  list.push_back (new CTioGzip);
+  list.push_back (new CTioXMLZipped);
+  list.push_back (new CTioODT);
+  list.push_back (new CTioABW);
+  list.push_back (new CTioFB2);
+  list.push_back (new CTioRTF);
+  list.push_back (new CTioEpub);
 
 #if defined (POPPLER_ENABLE) || defined(Q_OS_OS2)
-//#ifdef POPPLER_ENABLE
-  list.append (new CTioPDF);
+  list.push_back (new CTioPDF);
 #endif
 
 #if defined (DJVU_ENABLE) || defined(Q_OS_OS2)
-//#ifdef DJVU_ENABLE
-  list.append (new CTioDJVU);
+  list.push_back (new CTioDJVU);
 #endif
 }
 
 
 CTioHandler::~CTioHandler()
 {
-  while (! list.isEmpty())
-       delete list.takeFirst();
+  if (list.size() > 0)
+     for (vector <size_t>::size_type i = 0; i < list.size(); i++)
+          delete list[i];
 }
 
 
@@ -229,7 +233,7 @@ CTio* CTioHandler::get_for_fname (const QString &fname)
   CTio *instance;
   QString ext = file_get_ext (fname).toLower();
 
-  for (int i = 0; i < list.size(); i++)
+  for (vector <size_t>::size_type i = 0; i < list.size(); i++)
       {
        instance = list.at (i);
        if (instance->extensions.indexOf (ext) != -1)
@@ -281,7 +285,7 @@ bool CTioABW::load (const QString &fname)
 
   QStringList tags;
   tags.append ("p");
-  
+
   data = extract_text_from_xml (temp, tags);
 
   return true;
@@ -291,25 +295,25 @@ bool CTioABW::load (const QString &fname)
 bool CTioODT::load (const QString &fname)
 {
   data.clear();
-  
+
   CZipper zipper;
-  
+
   if (! zipper.read_as_utf8 (fname, "content.xml"))
      {
       qDebug() << "cannot read content.xml";
       return false;
      }
-   
+
   QXmlStreamReader xml (zipper.string_data);
- 
+
   bool tt = false;
-  while (! xml.atEnd()) 
+  while (! xml.atEnd())
         {
          xml.readNext();
 
          QString tag_name = xml.qualifiedName().toString().toLower();
-         
-         if (xml.isStartElement()) 
+
+         if (xml.isStartElement())
             {
              if (tag_name == "text:s")
                 {
@@ -321,15 +325,15 @@ bool CTioODT::load (const QString &fname)
                      fillval = fillval.fill (' ', av.toInt());
                      data.append (fillval);
                     }
-                 }   
+                 }
             }
-              
-         if (xml.isEndElement()) 
+
+         if (xml.isEndElement())
             {
              if (tag_name.startsWith ("text") && tag_name != "text:span")
                 tt = true;
             }
-         
+
          if (xml.isCharacters() && tt)
             {
              tt = false;
@@ -337,10 +341,10 @@ bool CTioODT::load (const QString &fname)
              data.append ("\n");
             }
         }
-    
-   if (xml.hasError()) 
+
+   if (xml.hasError())
       qDebug() << "xml parse error";
-   
+
   return true;
 }
 
@@ -366,34 +370,34 @@ CTioXMLZipped::CTioXMLZipped()
 bool CTioXMLZipped::load (const QString &fname)
 {
   data.clear();
-    
+
   QString source_fname;
-  QString ts;  
-  
+  QString ts;
+
   QString ext = file_get_ext (fname);
 
   if (ext == "kwd")
      {
       source_fname = "maindoc.xml";
       ts = "text";
-     } 
+     }
   else
   if (ext == "docx")
      {
       source_fname = "word/document.xml";
-      ts = "w:t";  
+      ts = "w:t";
      }
- 
-  
+
+
   CZipper zipper;
   if (! zipper.read_as_utf8 (fname, source_fname))
       return false;
- 
+
   QStringList tags;
   tags.append (ts);
-  
+
   data = extract_text_from_xml (zipper.string_data, tags);
- 
+
   return true;
 }
 
@@ -401,45 +405,125 @@ bool CTioXMLZipped::load (const QString &fname)
 CCharsetMagic::CCharsetMagic()
 {
   QStringList fnames = read_dir_entries (":/encsign");
-  
-  CSignaturesList *koi8u = NULL;
-  CSignaturesList *koi8r= NULL;
-  
-  foreach (QString fn, fnames)
-          {
-           QString fname = ":/encsign";
-           fname.append ("/"); 
-           fname.append (fn); 
-           
-           QByteArray a = file_load (fname);     
-           QList<QByteArray> bsl = a.split ('\n'); 
-  
-           CSignaturesList *sl = new CSignaturesList;
-           sl->encname = fn;
-           
-           if (fn == "KOI8-R")
-              koi8r = sl;
 
-           if (fn == "KOI8-U")
-              koi8u = sl;
-           
-           for (int i = 0; i < bsl.count(); i++) 
-               sl->words.append (bsl[i]);        
-                      
-           signatures.append (sl);          
-          }
-          
+  CSignaturesList *koi8u = NULL;
+  CSignaturesList *koi8r = NULL;
+
+  for (int i = 0; i < fnames.size(); i++) 
+      {
+
+       QString fn = fnames.at(i);
+       QString fname = ":/encsign/";
+       fname.append (fn);
+
+       QByteArray a = file_load (fname);
+       QList<QByteArray> bsl = a.split (',');
+
+       CSignaturesList *sl = new CSignaturesList;
+       sl->encname = fn;
+
+       if (fn == "KOI8-R")
+          koi8r = sl;
+
+       if (fn == "KOI8-U")
+          koi8u = sl;
+
+
+       //fill with signatures 
+       for (int i = 0; i < bsl.count(); i++)
+           sl->words.append (bsl[i]);
+
+       signatures.push_back (sl);
+      }
+
+//the following is needed to correct detection KOI8-R/U
+
+  std::vector<CSignaturesList*>::iterator it1 = std::find(signatures.begin(), signatures.end(), koi8u);
+  std::vector<CSignaturesList*>::iterator it2 = std::find(signatures.begin(), signatures.end(), koi8r);
+  std::swap (*it1, *it2);
+
+
+//  qDebug() << "signatures.size: " << signatures.size();
+/*
   int ku = signatures.indexOf (koi8u);
   int kr = signatures.indexOf (koi8r);
-          
-  signatures.swap (ku, kr);      
+
+//#if QT_VERSION >= 0x051300
+#if (QT_VERSION_MAJOR >= 5 && QT_VERSION_MINOR >= 13)
+  signatures.swapItemsAt (ku, kr);
+#else
+  signatures.swap (ku, kr);
+#endif
+*/
 }
 
 
-CCharsetMagic::~CCharsetMagic()  
+CCharsetMagic::~CCharsetMagic()
 {
-  for (int i = 0; i < signatures.count(); i++)
-      delete signatures.at (i);
+  if (signatures.size() > 0)
+     for (vector <size_t>::size_type i = 0; i < signatures.size(); i++)
+          delete signatures[i];
+}
+
+
+//from https://stackoverflow.com/questions/28270310/how-to-easily-detect-utf8-encoding-in-the-string
+bool is_valid_utf8(const char * string)
+{
+    if (!string)
+        return true;
+
+    const unsigned char * bytes = (const unsigned char *)string;
+    unsigned int cp;
+    int num;
+
+    while (*bytes != 0x00)
+    {
+        if ((*bytes & 0x80) == 0x00)
+        {
+            // U+0000 to U+007F 
+            cp = (*bytes & 0x7F);
+            num = 1;
+        }
+        else if ((*bytes & 0xE0) == 0xC0)
+        {
+            // U+0080 to U+07FF 
+            cp = (*bytes & 0x1F);
+            num = 2;
+        }
+        else if ((*bytes & 0xF0) == 0xE0)
+        {
+            // U+0800 to U+FFFF 
+            cp = (*bytes & 0x0F);
+            num = 3;
+        }
+        else if ((*bytes & 0xF8) == 0xF0)
+        {
+            // U+10000 to U+10FFFF 
+            cp = (*bytes & 0x07);
+            num = 4;
+        }
+        else
+            return false;
+
+        bytes += 1;
+        for (int i = 1; i < num; ++i)
+        {
+            if ((*bytes & 0xC0) != 0x80)
+                return false;
+            cp = (cp << 6) | (*bytes & 0x3F);
+            bytes += 1;
+        }
+
+        if ((cp > 0x10FFFF) ||
+            ((cp >= 0xD800) && (cp <= 0xDFFF)) ||
+            ((cp <= 0x007F) && (num != 1)) ||
+            ((cp >= 0x0080) && (cp <= 0x07FF) && (num != 2)) ||
+            ((cp >= 0x0800) && (cp <= 0xFFFF) && (num != 3)) ||
+            ((cp >= 0x10000) && (cp <= 0x1FFFFF) && (num != 4)))
+            return false;
+    }
+
+    return true;
 }
 
 
@@ -449,26 +533,30 @@ QString CCharsetMagic::guess_for_file (const QString &fname)
 
   QByteArray bafile = file_load (fname);
   QString ext = file_get_ext (fname);
-   
-  if (ext == "html" || 
-      ext == "htm" || 
+
+  if (ext == "html" ||
+      ext == "htm" ||
       ext == "xhtml")
      {
       QTextCodec *defcodec = QTextCodec::codecForName ("UTF-8");
       QTextCodec *codec = QTextCodec::codecForHtml (bafile, defcodec);
-      return codec->name(); 
+      return codec->name();
      }
 
-  for (int i = 0; i < signatures.count(); i++)
-       for (int x = 0; x < signatures[i]->words.count(); x++)
-           {
-            if (bafile.contains (signatures[i]->words[x]))
-               {
-                enc = signatures[i]->encname;
-                return enc;
-               }           
-           }
-  
+  if (is_valid_utf8 (bafile.data()))
+     return enc;
+
+  if (signatures.size() > 0)
+     for (vector <size_t>::size_type i = 0; i < signatures.size(); i++)
+          for (int x = 0; x < signatures[i]->words.count(); x++)
+              {
+               if (bafile.contains (signatures[i]->words[x]) > 0)
+                  {
+                   enc = signatures[i]->encname;
+                   return enc;
+                  }
+              }
+
   return enc;
 }
 
@@ -503,8 +591,6 @@ bool CTioFB2::load (const QString &fname)
   QXmlStreamReader xml (temp);
 
   bool tt = false;
- // bool title = false;
- // bool section = false;
 
   while (! xml.atEnd())
         {
@@ -516,12 +602,6 @@ bool CTioFB2::load (const QString &fname)
             {
              if (tag_name == ts)
                 tt = true;
-
-   //          if (tag_name == "title")
-     //           title = true;
-
-   //          if (tag_name == "section")
-     //           section = true;
             }
 
          if (xml.isEndElement())
@@ -530,17 +610,11 @@ bool CTioFB2::load (const QString &fname)
                  tt = false;
 
              if (tag_name == "title")
-                {
-       //          title = false;
                  data.append ("\n");
-                }
 
              if (tag_name == "section")
-                {
-       //          section = false;
                  data.append ("\n");
-                }
-             }
+            }
 
          if (tt && xml.isCharacters())
             {
@@ -589,7 +663,6 @@ QString rtf_strip (const QString &rtf)
   QChar ch;
   for (int j = start; j < length; j++)
       {
-
        ch = rtf.at (j);
 
        if (ch == '\\')//we are looking at the backslash
@@ -761,7 +834,6 @@ bool CTioRTF::load (const QString &fname)
 }
 
 #if defined (POPPLER_ENABLE) || defined(Q_OS_OS2)
-//#ifdef POPPLER_ENABLE
 
 CTioPDF::CTioPDF()
 {
@@ -773,32 +845,35 @@ CTioPDF::CTioPDF()
 bool CTioPDF::load (const QString &fname)
 {
   Poppler::Document *d = Poppler::Document::load (fname);
-  
-  if (! d || d->isLocked()) 
+
+  if (! d)
+     return false;
+
+  if (d->isLocked())
      {
       delete d;
       return false;
      }
-     
-     
-  int pages_count = d->numPages();   
-  
+
+
+  int pages_count = d->numPages();
+
   for (int i = 0; i < pages_count; i++)
       {
        Poppler::Page *p = d->page (i);
-      
+
        QList<Poppler::TextBox*> tb = p->textList();
-       
+
        for (int j = 0; j < tb.size(); j++)
            {
             data += tb[j]->text();
             //if (tb[j]->hasSpaceAfter())
             data += " ";
-          
+
             delete tb[j];
            }
       }
-     
+
   delete d;
   return true;
 }
@@ -806,10 +881,8 @@ bool CTioPDF::load (const QString &fname)
 #endif
 
 
-//#ifdef DJVU_ENABLE
 #if defined (DJVU_ENABLE) || defined(Q_OS_OS2)
 
-
 const char *detail = 0;
 int escape = 0;
 
@@ -825,18 +898,18 @@ void djvumsg_handle()
 
   if (! ctx)
     return;
-    
+
   msg = ddjvu_message_wait (ctx);
-    
+
   while ((msg = ddjvu_message_peek (ctx)))
         {
          if (msg->m_any.tag == DDJVU_ERROR)
             {
-             qDebug() << msg->m_error.message;              
+             qDebug() << msg->m_error.message;
              qDebug() << msg->m_error.filename << ":" << msg->m_error.lineno;
              return;
             }
-                
+
          ddjvu_message_pop(ctx);
         }
 }
@@ -845,20 +918,20 @@ void djvumsg_handle()
 void dopage (int pageno)
 {
   miniexp_t r = miniexp_nil;
-  
+
   const char *lvl = (detail) ? detail : "page";
-  
+
   while ((r = ddjvu_document_get_pagetext (doc, pageno, lvl)) == miniexp_dummy)
          djvumsg_handle();
 
   if ((r = miniexp_nth (5, r)) && miniexp_stringp (r))
      {
-      const char *s = miniexp_to_str (r); 
+      const char *s = miniexp_to_str (r);
       if (s)
          {
           temp_data_s.append (s);
-          temp_data_s.append ('\n');  
-         } 
+          temp_data_s.append ('\n');
+         }
      }
 }
 
@@ -874,22 +947,22 @@ bool CTioDJVU::load (const QString &fname)
 {
   if (! (ctx = ddjvu_context_create ("tea")))
      return false;
-     
+
   if (! (doc = ddjvu_document_create_by_filename (ctx, fname.toUtf8().data(), TRUE)))
      return false;
 
-    
+
   while (! ddjvu_document_decoding_done (doc))
         djvumsg_handle();
 
   int n = ddjvu_document_get_pagenum (doc);
-  
+
   for (int i = 0; i < n; i++)
       dopage (i);
-   
+
   if (doc)
     ddjvu_document_release (doc);
-    
+
   if (ctx)
     ddjvu_context_release (ctx);
 
@@ -903,7 +976,6 @@ bool CTioDJVU::load (const QString &fname)
 CTioEpub::CTioEpub()
 {
   ronly = true;
-
   extensions.append ("epub");
 }
 
@@ -911,38 +983,36 @@ CTioEpub::CTioEpub()
 bool CTioEpub::load (const QString &fname)
 {
   data.clear();
-  
+
   QStringList html_files;
-    
+
   QString source_fname;
-  QString ts;  
-  
+  QString ts;
+
   CZipper zipper;
   if (! zipper.read_as_utf8 (fname, "META-INF/container.xml"))
        return false;
-  
-  
+
   QString opf_fname;
   QString opf_dir;
-  
+
   int start = zipper.string_data.indexOf ("full-path=\"");
   int end = zipper.string_data.indexOf ("\"", start + 11);
-  
+
   opf_fname = zipper.string_data.mid (start + 11, end - start - 11);
   opf_dir = opf_fname.left (opf_fname.indexOf ("/"));
-   
+
   //std::cout << opf_fname.toStdString() << std::endl;
   //std::cout << opf_dir.toStdString() << std::endl;
 
   //READ FILES LIST. PARSE OPF FILE
-  
+
   if (! zipper.read_as_utf8 (fname, opf_fname))
        return false;
-  
-  
+
   QXmlStreamReader xml (zipper.string_data);
-  
-  while (! xml.atEnd()) 
+
+  while (! xml.atEnd())
         {
          xml.readNext();
 
@@ -955,27 +1025,37 @@ bool CTioEpub::load (const QString &fname)
                 html_files.append (opf_dir + "/" + attr_href);
              //std::cout << attr_href.toStdString() << std::endl;
             }
-        } 
-    
-  if (xml.hasError()) 
+        }
+
+  if (xml.hasError())
       qDebug() << "xml parse error";
 
+  for (int i = 0; i < html_files.size(); i++)
+      {
+       if (! zipper.read_as_utf8 (fname, html_files.at(i)))
+           return false;
+
+       QStringList tags;
+       tags.append ("p");
+
+       QString t = extract_text_from_xml (zipper.string_data, tags);
+       data += t;
+       data += "\n";
+      }
 
-  foreach (QString fn, html_files)
-          {
-           if (! zipper.read_as_utf8 (fname, fn))
-              return false;
-              
-           //QString t = strip_html (zipper.string_data);
-           QStringList tags;
-           tags.append ("p");
-          // tags.append ("h2");
-          
-           QString t = extract_text_from_xml (zipper.string_data, tags);
-          
-           data += t;
-           data += "\n";
-          }
-   
   return true;
 }
+
+
+QStringList CTioHandler::get_supported_exts()
+{
+  QStringList l;
+
+  for (std::vector <CTio*>::iterator t = list.begin(); t != list.end(); t++)
+       for (int i = 0; i < (*t)->extensions.size(); i++)
+           l.append ((*t)->extensions[i]);
+
+  l.append ("txt");
+  return l;
+}
+
