@@ -2,6 +2,9 @@
 #define TIO_H
 
 
+#include <vector>
+
+
 #include <QObject>
 #include <QList>
 #include <QByteArray>
@@ -19,14 +22,13 @@ public:
 };
 
 
-//FIXME: переписать под хэш?
 class CCharsetMagic: public QObject
 {
   Q_OBJECT
 
 public:
 
-  QList <CSignaturesList*> signatures;
+  std::vector <CSignaturesList*> signatures;
 
   CCharsetMagic();
   ~CCharsetMagic();
@@ -172,8 +174,6 @@ public:
 #endif
 
 
-
-
 #if defined(DJVU_ENABLE) || defined(Q_OS_OS2)
 class CTioDJVU: public CTioReadOnly
 {
@@ -194,7 +194,7 @@ class CTioHandler: public QObject
 
 public:
 
-  QList <CTio *> list;
+  std::vector <CTio *> list;
 
   CTioPlainText *default_handler;
 
@@ -202,6 +202,8 @@ public:
   ~CTioHandler();
 
   CTio* get_for_fname (const QString &fname);
+  QStringList get_supported_exts();
 };
 
 #endif // TIO_H
+
