@@ -166,7 +166,7 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>Test</source>
-        <translation type="vanished">Test</translation>
+        <translation>Test</translation>
     </message>
     <message>
         <source>New</source>
@@ -768,15 +768,15 @@ Voulez-vous le remplacer ?</translation>
     </message>
     <message>
         <source>MD5 checksum</source>
-        <translation>Somme MD5</translation>
+        <translation type="vanished">Somme MD5</translation>
     </message>
     <message>
         <source>MD4 checksum</source>
-        <translation>Somme MD4</translation>
+        <translation type="vanished">Somme MD4</translation>
     </message>
     <message>
         <source>SHA1 checksum</source>
-        <translation>Somme SHA1</translation>
+        <translation type="vanished">Somme SHA1</translation>
     </message>
     <message>
         <source>ZIP</source>
@@ -1141,7 +1141,7 @@ opera=opera %s</source>
     </message>
     <message>
         <source>SHA1 checksum for %1 is %2</source>
-        <translation>La somme SHA1 de %1 est %2</translation>
+        <translation type="vanished">La somme SHA1 de %1 est %2</translation>
     </message>
     <message>
         <source>file name: %1</source>
@@ -1850,10 +1850,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>files</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov, tea@list.ru&lt;br&gt;sites: semiletov.org/tea and tea.ourproject.org&lt;br&gt;development: github.com/psemiletov/tea-qt&lt;br&gt;VK: vk.com/teaeditor&lt;br&gt;read the Manual under the &lt;i&gt;Manual&lt;/i&gt; tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Copy block</source>
         <translation type="unfinished"></translation>
@@ -1946,10 +1942,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>UI style (restart needed)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>The famous input field. Use for search/replace, function parameters.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Guess encoding!</source>
         <translation type="unfinished"></translation>
@@ -1958,5 +1950,141 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>last modified: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The famous input field. Use for search/replace, function parameters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;TEA %1&lt;/b&gt; by Peter Semiletov, tea@list.ru&lt;br&gt;Sites: semiletov.org/tea and tea.ourproject.org&lt;br&gt;Git: github.com/psemiletov/tea-qt&lt;br&gt;AUR: https://aur.archlinux.org/packages/tea-qt/&lt;br&gt;VK: vk.com/teaeditor&lt;br&gt;read the Manual under the &lt;i&gt;Manual&lt;/i&gt; tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Anagram</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Checksum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MD5</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MD4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-2 SHA-224</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-2 SHA-256</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-2 SHA-384</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-2 SHA-512</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-3 SHA-224</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-3 SHA-256</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-3 SHA-384</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-3 SHA-512</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keccak-224</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keccak-256</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keccak-384</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keccak-512</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Enca for charset detection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot unzip and install plugin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-1 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-2 SHA-224 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-2 SHA-384 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-2 SHA-256 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-2 SHA-512 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-3 224 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-3 256 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-3 384 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA-3 512 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keccak 224 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keccak 256 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keccak 384 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keccak 512 checksum for %1 is %2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
