@@ -9,14 +9,30 @@ Peter Semiletov
 #include <QDir>
 #include <QImageReader>
 #include <QImage>
-
-
-
+#include <QProcess>
 
 #include "utils.h"
 
+
 /* file utils */
 
+QString guess_enc_for_file (const QString &fname)
+{
+  QString enc = "UTF-8";
+
+  QProcess p;
+  p.start ("enca", QStringList() << "-i" << fname);
+
+  if (! p.waitForStarted() || ! p.waitForFinished() ) 
+     return enc;
+
+  QString s = p.readAllStandardOutput();
+  if (! s.isEmpty())
+     enc = s.trimmed();
+
+  return enc;
+}
+
 
 bool file_is_writable (const QString &fname)
 {
@@ -54,7 +70,6 @@ QString change_file_ext (const QString &s, const QString &ext)
   if (i == -1)
      return (s + "." + ext);
 
-
   QString r (s);
   r.truncate (++i);
 
@@ -136,6 +151,7 @@ QByteArray file_load (const QString &fileName)
       return b;
 
   b = file.readAll();
+
   return b;
 }
 
@@ -182,16 +198,17 @@ bool char_is_bad (const QChar &c)
 
 void qstring_list_print (const QStringList &l)
 {
-  foreach (QString s, l)
-          qDebug() << s;
+  for (int i = 0; i < l.size(); i++)
+      qDebug() << l[i];
 }
 
 
-QStringList bytearray_to_stringlist (QList<QByteArray> a)
+QStringList bytearray_to_stringlist (const QList<QByteArray> &a)
 {
   QStringList r;
-  foreach (QByteArray i, a)
-          r.append (i.data());
+ 
+  for (int i = 0; i < a.size(); i++) 
+       r.append (a.at(i).data());
 
   return r;
 }
@@ -221,29 +238,6 @@ QString qstring_load_value (const QString &fileName, const QString &key, const Q
 }
 
 
-QString hash_keyval_to_string (const QHash <QString, QString> &h)
-{
-  QStringList l;
-
-  foreach (QString s, h.keys())
-          l.prepend (s.append ("=").append (h.value (s)));
-
-  return l.join ("\n").trimmed();
-}
-
-
-QHash <QString, QString> hash_load (const QString &fname)
-{
-  QHash<QString, QString> result;
-
-  if (! file_exists (fname))
-     return result;
-
-  result = stringlist_to_hash (qstring_load (fname).split ("\n"));
-  return result;
-}
-
-
 QHash <QString, QString> hash_load_keyval (const QString &fname)
 {
   QHash <QString, QString> result;
@@ -253,26 +247,12 @@ QHash <QString, QString> hash_load_keyval (const QString &fname)
 
   QStringList l = qstring_load (fname).split ("\n");
 
-  foreach (QString s, l)
-          {
-           QStringList sl = s.split ("=");
-           if (sl.size() > 1)
-               result.insert (sl[0], sl[1]);
-          }
-
-  return result;
-}
-
-
-QHash <QString, QString> stringlist_to_hash (const QStringList &l)
-{
-  QHash <QString, QString> result;
-
-  if (l.empty())
-     return result;
-
-  foreach (QString s, l)
-          result.insert (s, s);
+  for (QList <QString>::iterator i = l.begin(); i != l.end(); i++)
+      {
+       QStringList sl = i->split ("=");
+       if (sl.size() > 1)
+          result.insert (sl.at(0), sl.at(1));
+      }
 
   return result;
 }
@@ -287,12 +267,12 @@ bool is_image (const QString &filename)
 
   QList <QByteArray> a = QImageReader::supportedImageFormats();
 
-  foreach (QByteArray x, a)
-          {
-           QString t (x.data());
-           if (filename.endsWith (t.prepend ("."), Qt::CaseInsensitive))
-              return true;
-          }
+  for (QList <QByteArray>::iterator i = a.begin(); i != a.end(); i++)
+      {
+       QString t (i->data());
+       if (filename.endsWith (t.prepend ("."), Qt::CaseInsensitive))
+          return true;
+      }
 
   return false;
 }
@@ -329,9 +309,10 @@ QString get_insert_image (const QString &file_name, const QString &full_path, co
   if (markup_mode == "Lout")
       result = QString ("@IncludeGraphic {%1}").arg (dir.relativeFilePath (full_path));
 
-   return result;
+  return result;
 }
 
+
 /* class functions */
 
 void CFilesList::iterate (QFileInfo &fi)
@@ -339,14 +320,13 @@ void CFilesList::iterate (QFileInfo &fi)
   if (fi.isDir())
      {
       QDir d (fi.absoluteFilePath());
-      QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files |
-                                          QDir::Readable | QDir::NoDotAndDotDot);
+      QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files | QDir::Readable | QDir::NoDotAndDotDot);
       for (int i = 0; i < lfi.count(); i++)
            iterate (lfi[i]);
      }
   else
   if (fi.isFile())
-      list.append (fi.absoluteFilePath());
+     list.append (fi.absoluteFilePath());
 }
 
 
@@ -354,8 +334,7 @@ void CFilesList::get (const QString &path)
 {
   list.clear();
   QDir d (path);
-  QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files |
-                                      QDir::Readable | QDir::NoDotAndDotDot);
+  QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files | QDir::Readable | QDir::NoDotAndDotDot);
   for (int i = 0; i < lfi.count(); i++)
       iterate (lfi[i]);
 }
@@ -368,13 +347,13 @@ CFTypeChecker::CFTypeChecker (const QStringList &fnames, const QStringList &exts
 }
 
 
-bool CFTypeChecker::check (const QString &fname)
+bool CFTypeChecker::check (const QString &fname) const
 {
   bool result = false;
 
 #if QT_VERSION >= 0x050000
   QMimeType mime = db.mimeTypeForFile(fname);
-  if (mime.inherits("text/plain"))
+  if (mime.inherits ("text/plain"))
      result = true;
 #endif
 
@@ -390,7 +369,7 @@ bool CFTypeChecker::check (const QString &fname)
 }
 
 
-QStringList CFTypeChecker::get_supported_exts()
+QStringList CFTypeChecker::get_supported_exts() const
 {
   QStringList l;
 
@@ -398,3 +377,4 @@ QStringList CFTypeChecker::get_supported_exts()
   l.append ("txt");
   return l;
 }
+
